------------------------------------------------------------------------------------------------------------------------

-- VN_550921_Rung_Sat.lua

-- Author: Jason Petho
-- Scripter: Robert ("Berto") Osterlund

------------------------------------------------------------------------------------------------------------------------

function on_startup () -- DO NOT REMOVE

    -- set/unset optional rules (effective in on_startup() only!)
    -- for example:
    -- set_option(OPTHISTORICALLZS)
    -- unset_option(OPTFACING)
    -- to specify every optional rule:
    -- set_options(OPTFIREMAP|OPTEXTFOW|OPTCOMMANDCTRL|OPTVISIBILITY)

    -- set/unset move tracking globally (maybe unset if performance lags)
    -- set_move_tracking()
    -- unset_move_tracking()

    -- for deep debugging:
    --traceon()

    init_constants ()
    init_variables ()

    set_org_lists()

    log(LUALOG, LOG_INFO,
        "game " .. game() ..
        ", game name " .. game_name() ..
        ", scenario " .. scenario() ..
        ", missions Side A " .. missions("a") ..
        ", missions Side B " .. missions("b") ..
        ", region " .. region() ..
        ", region name " .. region_name() ..
        ", biome " .. biome() ..
        ", biome name " .. biome_name() ..
        ", condition ground " .. condition(CONDITION_GROUND) ..
        ", condition water " .. condition(CONDITION_WATER) ..
        ", condition tree " .. condition(CONDITION_TREE) ..
        ", condition field " .. condition(CONDITION_FIELD)
       )

end

------------------------------------------------------------------------------------------------------------------------

function on_resume () -- DO NOT REMOVE

    -- see on_startup()
    -- set_move_tracking()
    -- unset_move_tracking()

    -- for deep debugging:
    --traceon()

    init_constants ()

    set_org_lists(current_turn(), current_side())

end

------------------------------------------------------------------------------------------------------------------------

function init_constants ()

    -- initialize names and labels unvarying through the course of the scenario
    -- also define here lists with "holes" (index gaps) (such lists are not saved)
    -- called in on_startup(), and potentially again (and again) in any subsequent on_resume()

    -- Side "a" and "b" values with descriptive names
    SIDE_A = "a" -- _NATION ## (in user.lua)
    ARVN_SIDE = SIDE_A
    VNA_SIDE = SIDE_A
    SIDE_B = "b" -- _NATION ## (in user.lua)
    BX_SIDE = SIDE_B

    OBJECTIVES = {}
    OBJECTIVES[1] = "27,38" -- 1-40[2/2] 11
    OBJECTIVES[2] = "34,33" -- 1-40[2/2] 11
    OBJECTIVES[3] = "42,55" -- 1-40[2/2] 21
    OBJECTIVES[4] = "43,35" -- 1-40[2/2] 21
    OBJECTIVES[5] = "44,48" -- 1-40[2/2] 21
    OBJECTIVES[6] = "45,42" -- 1-40[2/2] 21
    OBJECTIVES[7] = "46,43" -- 1-40[2/2] 21
    OBJECTIVES[8] = "48,7" -- 1-40[2/2] 21
    OBJECTIVES[9] = "49,28" -- 1-40[2/2] 21
    OBJECTIVES[10] = "52,31" -- 1-40[2/2] 21
    OBJECTIVES[11] = "52,54" -- 1-40[2/2] 21
    OBJECTIVES[12] = "53,37" -- 1-40[2/2] 21
    OBJECTIVES[13] = "61,13" -- 1-40[2/2] 21
    OBJECTIVES[14] = "66,37" -- 1-40[2/2] 21
    OBJECTIVES[15] = "68,14" -- 1-40[2/2] 21
    OBJECTIVES[16] = "70,2" -- 1-40[2/2] 21
    OBJECTIVES[17] = "72,3" -- 1-40[2/2] 21
    OBJECTIVES[18] = "74,56" -- 1-40[2/2] 21
    OBJECTIVES[19] = "74,59" -- 1-40[2/2] 21
    OBJECTIVES[20] = "75,51" -- 1-40[2/2] 21
    OBJECTIVES[21] = "75,56" -- 1-40[2/2] 21
    OBJECTIVES[22] = "76,28" -- 1-40[2/2] 21
    OBJECTIVES[23] = "76,29" -- 1-40[2/2] 21
    OBJECTIVES[24] = "77,15" -- 1-40[2/2] 21
    OBJECTIVES[25] = "82,12" -- 1-40[2/2] 21
    OBJECTIVES[26] = "82,42" -- 1-40[2/2] 21
    OBJECTIVES[27] = "85,18" -- 1-40[2/2] 21
    OBJECTIVES[28] = "87,57" -- 1-40[2/2] 21
    OBJECTIVES[29] = "90,29" -- 1-40[2/2] 21
    OBJECTIVES[30] = "90,66" -- 1-40[2/2] 21
    OBJECTIVES[31] = "93,24" -- 1-40[2/2] 21
    OBJECTIVES[32] = "95,50" -- 1-40[2/2] 21
    OBJECTIVES[33] = "98,26" -- 1-40[2/2] 21
    OBJECTIVES[34] = "101,20" -- 1-40[2/2] 21

    LANDING_ZONES = {}
    LANDING_ZONES[1] = "62,13"
    LANDING_ZONES[2] = "63,14"
    LANDING_ZONES[3] = "64,14"
    LANDING_ZONES[4] = "65,15"

    EMBARK_PTS = {}
    -- and also, for example (indexing from 1 thru x):
    -- Side A
    -- EMBARK_PTS[1] = "45,69"
    -- ...
    -- Side B
    -- ...
    -- EMBARK_PTS[x] = "20,48"

    DISEMBARK_PTS = {}
    -- and also, for example (indexing from 1 thru x):
    -- Side A
    -- DISEMBARK_PTS[1] = "41,69"
    -- ...
    -- Side B
    -- ...
    -- DISEMBARK_PTS[x] = "13,56"

    -- others ...

end

------------------------------------------------------------------------------------------------------------------------

function set_org_lists (turn, side)

    -- called in on_startup(), in every on_next_turn(), and potentially again (and again) in any subsequent on_resume()

    --traceon()

    turn = turn or 1
    side = side or "a"

    ALLA = counters_all(SIDE_A)
    ALLB = counters_all(SIDE_B)

    -- auto-generated org lists to follow; rename, resequence, regroup, and reorganize as necessary

    -- KEY:

    -- [P] Platoon
    -- [C] Company
    -- [B] Battalion
    -- [R] Regiment
    -- [G] Brigade
    -- [D] Division
    -- [K] Corps
    -- [A] Army

    _BINH_XUYEN_PRIVATE_ARMY_1 = {2,3,5,7,8,9,10,12,13,14,15,17,18,19,20,22,23,24,25,36,38,39,40,41,43,44,45,48,49,50,53,54,55,67,69,70,71,74,75,76,79,80,81,82,84,85,86,95,96,98,100,101,102,103,105,106,107,110,111,112,115,116,117,127,130,131,134,135,482,483,484,485,486,487,488,489,490,146,147,148,149,150,153,154,157,158,159,160,161,162,163,164,165,166,491,492,493,494,495,496,497,498,499,500,501} -- [R] [2122218] Binh Xuyen Private Army

    _TRUNG_DOAN_HQ_2 = {2} -- [P] [74,59] [213014] VM Regimental HQ (foot)

    _BAY_VIEN_3 = {3} -- [P] [75,56] [214204] VM Commander 4

    _1ST_1ST_BINH_XUYEN_INF_BTN_48_US_4 = {5,7,8,9,10,12,13,14,15,17,18,19,20,22,23,24,25} -- [B] [2112207] 1st/1st Binh Xuyen Infantry Battalion 48 - US

    _TIEU_DOAN_HQ_5 = {5} -- [P] [76,28] [213015] VM Battalion HQ (foot)

    _C1_1ST_1ST_RIFLE_COY_48_US_6 = {7,8,9,10} -- [C] [2102218] C1/1st/1st Rifle Company 48 - US
    _1ST_VM_RIFLE_48_7 = {7} -- [P] [90,33] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _2ND_VM_RIFLE_48_8 = {8} -- [P] [90,32] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _3RD_VM_RIFLE_48_9 = {9} -- [P] [89,33] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _MORTAR_10 = {10} -- [P] [89,33] [211008] VM 50mm Mortars

    _C2_1ST_1ST_RIFLE_COY_48_US_11 = {12,13,14,15} -- [C] [2102218] C2/1st/1st Rifle Company 48 - US
    _1ST_VM_RIFLE_48_12 = {12} -- [P] [76,29] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _2ND_VM_RIFLE_48_13 = {13} -- [P] [76,29] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _3RD_VM_RIFLE_48_14 = {14} -- [P] [76,28] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _MORTAR_15 = {15} -- [P] [76,28] [211008] VM 50mm Mortars

    _C3_1ST_1ST_RIFLE_COY_48_US_16 = {17,18,19,20} -- [C] [2102218] C3/1st/1st Rifle Company 48 - US
    _1ST_VM_RIFLE_48_17 = {17} -- [P] [66,23] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _2ND_VM_RIFLE_48_18 = {18} -- [P] [66,23] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _3RD_VM_RIFLE_48_19 = {19} -- [P] [66,23] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _MORTAR_20 = {20} -- [P] [66,23] [211008] VM 50mm Mortars

    _C4_1ST_1ST_DAI_DOI_HOA_LUC_48_81MM_21 = {22,23,24,25} -- [C] [2102219] C4/1st/1st Dai Doi Hoa Luc 48 - 81mm
    _MORTAR_22 = {22} -- [P] [76,29] [211015] VM 81mm Mortars
    _MEDIUM_MACHINE_GUN_23 = {23} -- [P] [73,21] [212067] VM Medium Machine Gun (US)
    _MEDIUM_MACHINE_GUN_24 = {24} -- [P] [63,31] [212067] VM Medium Machine Gun (US)
    _BAZOOKA_TOAN_25 = {25} -- [P] [62,32] [212070] VM Bazooka Team

    _1ST_2ND_BINH_XUYEN_INF_BTN_48_US_35 = {36,38,39,40,41,43,44,45,48,49,50,53,54,55} -- [B] [2112207] 1st/2nd Binh Xuyen Infantry Battalion 48 - US

    _TIEU_DOAN_HQ_36 = {36} -- [P] [82,42] [213015] VM Battalion HQ (foot)

    _C1_1ST_2ND_RIFLE_COY_48_US_37 = {38,39,40,41} -- [C] [2102218] C1/1st/2nd Rifle Company 48 - US
    _1ST_VM_RIFLE_48_38 = {38} -- [P] [66,37] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _2ND_VM_RIFLE_48_39 = {39} -- [P] [66,38] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _3RD_VM_RIFLE_48_40 = {40} -- [P] [66,37] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _MORTAR_41 = {41} -- [P] [66,38] [211008] VM 50mm Mortars

    _C2_1ST_2ND_RIFLE_COY_48_US_42 = {43,44,45} -- [C] [2102218] C2/1st/2nd Rifle Company 48 - US
    _1ST_VM_RIFLE_48_43 = {43} -- [P] [76,38] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _2ND_VM_RIFLE_48_44 = {44} -- [P] [76,38] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _3RD_VM_RIFLE_48_45 = {45} -- [P] [76,37] [212040] VM Rifle Platoon 48 (U.S. Arms)

    _C3_1ST_2ND_RIFLE_COY_48_US_47 = {48,49,50} -- [C] [2102218] C3/1st/2nd Rifle Company 48 - US
    _1ST_VM_RIFLE_48_48 = {48} -- [P] [88,50] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _2ND_VM_RIFLE_48_49 = {49} -- [P] [88,49] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _3RD_VM_RIFLE_48_50 = {50} -- [P] [88,49] [212040] VM Rifle Platoon 48 (U.S. Arms)

    _C4_1ST_2ND_DAI_DOI_HOA_LUC_48_81MM_52 = {53,54,55} -- [C] [2102219] C4/1st/2nd Dai Doi Hoa Luc 48 - 81mm
    _MORTAR_53 = {53} -- [P] [82,42] [211015] VM 81mm Mortars
    _MEDIUM_MACHINE_GUN_54 = {54} -- [P] [82,42] [212067] VM Medium Machine Gun (US)
    _MEDIUM_MACHINE_GUN_55 = {55} -- [P] [69,48] [212067] VM Medium Machine Gun (US)

    _1ST_5TH_BINH_XUYEN_INF_BTN_48_US_66 = {67,69,70,71,74,75,76,79,80,81,82,84,85,86,95,96} -- [B] [2112207] 1st/5th Binh Xuyen Infantry Battalion 48 - US

    _TIEU_DOAN_HQ_67 = {67} -- [P] [71,60] [213015] VM Battalion HQ (foot)

    _C1_1ST_5TH_RIFLE_COY_48_US_68 = {69,70,71} -- [C] [2102218] C1/1st/5th Rifle Company 48 - US
    _1ST_VM_RIFLE_48_69 = {69} -- [P] [74,56] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _2ND_VM_RIFLE_48_70 = {70} -- [P] [71,58] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _3RD_VM_RIFLE_48_71 = {71} -- [P] [74,55] [212040] VM Rifle Platoon 48 (U.S. Arms)

    _C2_1ST_5TH_RIFLE_COY_48_US_73 = {74,75,76} -- [C] [2102218] C2/1st/5th Rifle Company 48 - US
    _1ST_VM_RIFLE_48_74 = {74} -- [P] [71,65] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _2ND_VM_RIFLE_48_75 = {75} -- [P] [70,65] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _3RD_VM_RIFLE_48_76 = {76} -- [P] [71,65] [212040] VM Rifle Platoon 48 (U.S. Arms)

    _C3_1ST_5TH_RIFLE_COY_48_US_78 = {79,80,81,82} -- [C] [2102218] C3/1st/5th Rifle Company 48 - US
    _1ST_VM_RIFLE_48_79 = {79} -- [P] [52,54] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _2ND_VM_RIFLE_48_80 = {80} -- [P] [52,54] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _3RD_VM_RIFLE_48_81 = {81} -- [P] [49,54] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _MORTAR_82 = {82} -- [P] [51,54] [211008] VM 50mm Mortars

    _C4_1ST_5TH_DAI_DOI_HOA_LUC_48_81MM_83 = {84,85,86} -- [C] [2102219] C4/1st/5th Dai Doi Hoa Luc 48 - 81mm
    _MORTAR_84 = {84} -- [P] [73,58] [211015] VM 81mm Mortars
    _MEDIUM_MACHINE_GUN_85 = {85} -- [P] [71,60] [212067] VM Medium Machine Gun (US)
    _MEDIUM_MACHINE_GUN_86 = {86} -- [P] [75,56] [212067] VM Medium Machine Gun (US)

    _LOGISTICS_COY_LEVEL_1_48_88 = {95} -- [C] [2109207] Logistics Company - Level 1 - 48

    _SUPPLY_CACHE_95 = {95} -- [P] [42,55] [218811] Supply Cache (VP)

    _DAC_CONG_96 = {96} -- [P] [42,55] [212080] VM Engineer Platoon

    _1ST_3RD_BINH_XUYEN_INF_BTN_48_US_97 = {98,100,101,102,103,105,106,107,110,111,112,115,116,117,127} -- [B] [2112207] 1st/3rd Binh Xuyen Infantry Battalion 48 - US

    _TIEU_DOAN_HQ_98 = {98} -- [P] [82,12] [213015] VM Battalion HQ (foot)

    _C1_1ST_3RD_RIFLE_COY_48_US_99 = {100,101,102,103} -- [C] [2102218] C1/1st/3rd Rifle Company 48 - US
    _1ST_VM_RIFLE_48_100 = {100} -- [P] [72,3] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _2ND_VM_RIFLE_48_101 = {101} -- [P] [70,2] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _3RD_VM_RIFLE_48_102 = {102} -- [P] [82,12] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _MORTAR_103 = {103} -- [P] [82,12] [211008] VM 50mm Mortars

    _C2_1ST_3RD_RIFLE_COY_48_US_104 = {105,106,107} -- [C] [2102218] C2/1st/3rd Rifle Company 48 - US
    _1ST_VM_RIFLE_48_105 = {105} -- [P] [61,13] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _2ND_VM_RIFLE_48_106 = {106} -- [P] [48,7] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _3RD_VM_RIFLE_48_107 = {107} -- [P] [61,12] [212040] VM Rifle Platoon 48 (U.S. Arms)

    _C3_1ST_3RD_RIFLE_COY_48_US_109 = {110,111,112} -- [C] [2102218] C3/1st/3rd Rifle Company 48 - US
    _1ST_VM_RIFLE_48_110 = {110} -- [P] [85,19] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _2ND_VM_RIFLE_48_111 = {111} -- [P] [87,18] [212040] VM Rifle Platoon 48 (U.S. Arms)
    _3RD_VM_RIFLE_48_112 = {112} -- [P] [85,18] [212040] VM Rifle Platoon 48 (U.S. Arms)

    _C4_1ST_3RD_DAI_DOI_HOA_LUC_48_81MM_114 = {115,116,117} -- [C] [2102219] C4/1st/3rd Dai Doi Hoa Luc 48 - 81mm
    _MORTAR_115 = {115} -- [P] [82,12] [211015] VM 81mm Mortars
    _MEDIUM_MACHINE_GUN_116 = {116} -- [P] [62,12] [212067] VM Medium Machine Gun (US)
    _MEDIUM_MACHINE_GUN_117 = {117} -- [P] [85,18] [212067] VM Medium Machine Gun (US)

    _DAC_CONG_127 = {127} -- [P] [61,13] [212080] VM Engineer Platoon

    _FIRE_SUPPORT_COY_50_82MM_128 = {130,131} -- [C] [2102227] Fire Support Company 50 - 82mm
    _MEDIUM_MACHINE_GUN_130 = {130} -- [P] [59,6] [212069] VM Medium Machine Gun (Soviet)
    _MEDIUM_MACHINE_GUN_131 = {131} -- [P] [59,6] [212069] VM Medium Machine Gun (Soviet)

    _RECONNAISSANCE_COY_50_133 = {134,135} -- [C] [2106201] Reconnaissance Company 50
    _THAM_BAO_134 = {134} -- [P] [58,5] [212049] VM Rifle Platoon 50 A (U.S. Arms)
    _THAM_BAO_135 = {135} -- [P] [58,5] [212049] VM Rifle Platoon 50 A (U.S. Arms)

    _LOGISTICS_COY_LEVEL_3_48_468 = {482,483,484,485,486,487,488,489,490} -- [C] [2109209] Logistics Company - Level 3 - 48
    _SUPPLY_CACHE_482 = {482} -- [P] [T1: 68,55] [218811] Supply Cache (VP)
    _SUPPLY_CACHE_483 = {483} -- [P] [T1: 60,59] [218811] Supply Cache (VP)
    _SUPPLY_CACHE_484 = {484} -- [P] [T1: 60,27] [218811] Supply Cache (VP)
    _SUPPLY_DEPOT_485 = {485} -- [P] [74,59] [218808] Fixed Supply Depot (VP)
    _SUPPLY_DEPOT_486 = {486} -- [P] [T1: 91,50] [218808] Fixed Supply Depot (VP)
    _SUPPLY_DEPOT_487 = {487} -- [P] [T1: 51,53] [218808] Fixed Supply Depot (VP)
    _JUNGLE_FACTORY_488 = {488} -- [P] [T1: 77,41] [218809] Jungle Factory
    _JUNGLE_FACTORY_489 = {489} -- [P] [T1: 59,47] [218809] Jungle Factory
    _JUNGLE_FACTORY_490 = {490} -- [P] [T1: 90,38] [218809] Jungle Factory

    _LOGISTICS_COY_LEVEL_2_48_138 = {146,147,148,149} -- [C] [2109208] Logistics Company - Level 2 - 48
    _SUPPLY_CACHE_146 = {146} -- [P] [T1: 82,28] [218811] Supply Cache (VP)
    _SUPPLY_CACHE_147 = {147} -- [P] [70,33] [218811] Supply Cache (VP)
    _SUPPLY_CACHE_148 = {148} -- [P] [T1: 73,25] [218811] Supply Cache (VP)
    _JUNGLE_FACTORY_149 = {149} -- [P] [T1: 71,67] [218809] Jungle Factory

    _LIGHT_TRUCK_150 = {150} -- [P] [87,18] [217016] Light Truck

    _MEDIUM_TRUCK_153 = {153} -- [P] [85,19] [217020] Medium Truck

    _MEDIUM_TRUCK_154 = {154} -- [P] [48,7] [217020] Medium Truck

    _SAMPANS_157 = {157} -- [P] [74,29] [216808] Sampans

    _SAMPANS_158 = {158} -- [P] [75,32] [216808] Sampans

    _SAMPANS_159 = {159} -- [P] [74,30] [216808] Sampans

    _SAMPANS_160 = {160} -- [P] [86,41] [216808] Sampans

    _SAMPANS_161 = {161} -- [P] [88,45] [216808] Sampans

    _JUNKS_162 = {162} -- [P] [73,56] [216809] Junks

    _JUNKS_163 = {163} -- [P] [69,25] [216809] Junks

    _JUNKS_164 = {164} -- [P] [78,47] [216809] Junks

    _JUNKS_165 = {165} -- [P] [88,56] [216809] Junks

    _JUNKS_166 = {166} -- [P] [73,59] [216809] Junks

    _AAMG_491 = {491} -- [P] [75,57] [212065] VM Anti-Aircraft Machine Gun

    _AAMG_492 = {492} -- [P] [77,53] [212065] VM Anti-Aircraft Machine Gun

    _AAMG_493 = {493} -- [P] [77,43] [212065] VM Anti-Aircraft Machine Gun

    _AAMG_494 = {494} -- [P] [67,29] [212065] VM Anti-Aircraft Machine Gun

    _SNIPER_495 = {495} -- [P] [45,42] [212027] VM Sniper

    _SNIPER_496 = {496} -- [P] [44,51] [212027] VM Sniper

    _SNIPER_497 = {497} -- [P] [96,24] [212027] VM Sniper

    _SNIPER_498 = {498} -- [P] [58,26] [212027] VM Sniper

    _SNIPER_499 = {499} -- [P] [52,31] [212027] VM Sniper

    _57MM_RCLR_500 = {500} -- [P] [84,44] [219006] 57mm Recoilless Rifles

    _57MM_RCLR_501 = {501} -- [P] [52,37] [219006] 57mm Recoilless Rifles

    _OPERATION_HOANG_DIEU_167 = {460,168,271,464,273,274,275,276,467,279,280,281,282,285,286,287,288,297,298,299,300,302,465,304,305,306,307,310,311,312,313,316,317,318,319,328,329,330,331,170,461,172,173,174,176,177,178,180,181,182,184,185,187,442,462,444,445,446,448,449,450,452,453,454,456,457,459,227,463,229,230,231,233,234,235,237,238,239,241,242,244,378,380,381,382,383,384,385,386,387,388,389,391,392,393,394,395,396,397,398,399,400,412,414,416,417,421,422,426,427,432,433,434,435,430,437,438,439,440,266,267} -- [G] [1132201] Operation Hoang Dieu

    _VNA_HQ_460 = {460} -- [P] [T998: 46,0] [113014] VNA Brigade HQ (foot)

    _AIRBORNE_HQ_168 = {168} -- [P] [T4: 67,12] [113026] VNAF Airborne Brigade HQ (foot)

    _154TH_INF_RGT_55_B_268 = {271,464,273,274,275,276,467,279,280,281,282,285,286,287,288,297,298,299,300,302,465,304,305,306,307,310,311,312,313,316,317,318,319,328,329,330,331} -- [R] [1122232] 154th Infantry Regiment 55 - B

    _22ND_154TH_INF_BTN_55_B_270 = {271,464,273,274,275,276,467,279,280,281,282,285,286,287,288,297,298,299,300} -- [B] [1112226] 22nd/154th Infantry Battalion 55 - B

    _HQ_271 = {271} -- [P] [32,49] [113010] ARVN Battalion HQ (foot)

    _22ND_154TH_464 = {464} -- [P] [32,49] [114001] ARVN Commander 1

    _1ST_22ND_INF_COY_55_B_272 = {273,274,275,276} -- [C] [1102239] 1st/22nd Infantry Company 55 - B
    _1ST_PLT_273 = {273} -- [P] [32,50] [112007] ARVN Infantry Platoon 55 B
    _2ND_PLT_274 = {274} -- [P] [32,50] [112007] ARVN Infantry Platoon 55 B
    _3RD_PLT_275 = {275} -- [P] [31,51] [112007] ARVN Infantry Platoon 55 B
    _MMG_48_276 = {276} -- [P] [31,51] [112071] M1919A4 Machine Gun

    _2ND_22ND_INF_COY_55_B_278 = {467,279,280,281,282} -- [C] [1102239] 2nd/22nd Infantry Company 55 - B
    _2ND_22ND_467 = {467} -- [P] [32,48] [114001] ARVN Commander 1
    _1ST_PLT_279 = {279} -- [P] [32,48] [112007] ARVN Infantry Platoon 55 B
    _2ND_PLT_280 = {280} -- [P] [32,48] [112007] ARVN Infantry Platoon 55 B
    _3RD_PLT_281 = {281} -- [P] [32,49] [112007] ARVN Infantry Platoon 55 B
    _MMG_48_282 = {282} -- [P] [32,49] [112071] M1919A4 Machine Gun

    _3RD_22ND_INF_COY_55_B_284 = {285,286,287,288} -- [C] [1102239] 3rd/22nd Infantry Company 55 - B
    _1ST_PLT_285 = {285} -- [P] [31,50] [112007] ARVN Infantry Platoon 55 B
    _2ND_PLT_286 = {286} -- [P] [31,50] [112007] ARVN Infantry Platoon 55 B
    _3RD_PLT_287 = {287} -- [P] [31,50] [112007] ARVN Infantry Platoon 55 B
    _MMG_48_288 = {288} -- [P] [31,50] [112071] M1919A4 Machine Gun

    _22NDWEAPONS_COY_55_296 = {297,298,299,300} -- [C] [1102241] 22ndWeapons Company 55
    _ENGINEER_297 = {297} -- [P] [31,49] [112034] Engineer Platoon 55
    _MMG_298 = {298} -- [P] [31,49] [112071] M1919A4 Machine Gun
    _75MM_RR_299 = {299} -- [P] [31,49] [119005] M20 75mm Recoilless Rifle
    _81MM_MORTAR_300 = {300} -- [P] [31,49] [111011] M1 81mm Mortars

    _58TH_154TH_INF_BTN_55_B_301 = {302,465,304,305,306,307,310,311,312,313,316,317,318,319,328,329,330,331} -- [B] [1112226] 58th/154th Infantry Battalion 55 - B

    _HQ_302 = {302} -- [P] [34,33] [113010] ARVN Battalion HQ (foot)

    _58TH_154TH_465 = {465} -- [P] [34,33] [114001] ARVN Commander 1

    _1ST_58TH_INF_COY_55_B_303 = {304,305,306,307} -- [C] [1102239] 1st/58th Infantry Company 55 - B
    _1ST_PLT_304 = {304} -- [P] [36,32] [112007] ARVN Infantry Platoon 55 B
    _2ND_PLT_305 = {305} -- [P] [36,33] [112007] ARVN Infantry Platoon 55 B
    _3RD_PLT_306 = {306} -- [P] [35,33] [112007] ARVN Infantry Platoon 55 B
    _MMG_48_307 = {307} -- [P] [35,33] [112071] M1919A4 Machine Gun

    _2ND_58TH_INF_COY_55_B_309 = {310,311,312,313} -- [C] [1102239] 2nd/58th Infantry Company 55 - B
    _1ST_PLT_310 = {310} -- [P] [32,36] [112007] ARVN Infantry Platoon 55 B
    _2ND_PLT_311 = {311} -- [P] [32,36] [112007] ARVN Infantry Platoon 55 B
    _3RD_PLT_312 = {312} -- [P] [32,35] [112007] ARVN Infantry Platoon 55 B
    _MMG_48_313 = {313} -- [P] [32,35] [112071] M1919A4 Machine Gun

    _3RD_58TH_INF_COY_55_B_315 = {316,317,318,319} -- [C] [1102239] 3rd/58th Infantry Company 55 - B
    _1ST_PLT_316 = {316} -- [P] [27,38] [112007] ARVN Infantry Platoon 55 B
    _2ND_PLT_317 = {317} -- [P] [27,38] [112007] ARVN Infantry Platoon 55 B
    _3RD_PLT_318 = {318} -- [P] [27,39] [112007] ARVN Infantry Platoon 55 B
    _MMG_48_319 = {319} -- [P] [27,39] [112071] M1919A4 Machine Gun

    _58TH_WEAPONS_COY_55_327 = {328,329,330,331} -- [C] [1102241] 58th Weapons Company 55
    _ENGINEER_328 = {328} -- [P] [33,36] [112034] Engineer Platoon 55
    _MMG_329 = {329} -- [P] [36,33] [112071] M1919A4 Machine Gun
    _75MM_RR_330 = {330} -- [P] [33,36] [119005] M20 75mm Recoilless Rifle
    _81MM_MORTAR_331 = {331} -- [P] [35,33] [111011] M1 81mm Mortars

    _1ST_PARACHUTE_BTN_55_A_169 = {170,461,172,173,174,176,177,178,180,181,182,184,185,187} -- [B] [1112228] 1st Parachute Battalion 55 - A

    _HQ_170 = {170} -- [P] [T1: 48,19] [113021] VNAF Airborne Battalion HQ (foot)

    _1ST_PARACHUTE_461 = {461} -- [P] [T1: 48,19] [114016] Airborne Commander 2

    _1ST_1ST_PARACHUTE_COY_55_A_171 = {172,173,174} -- [C] [1102243] 1st/1st Parachute Company 55 - A
    _1ST_PLT_172 = {172} -- [P] [T1: 49,20] [112022] Parachute Platoon 55 A
    _2ND_PLT_173 = {173} -- [P] [T1: 49,20] [112022] Parachute Platoon 55 A
    _3RD_PLT_174 = {174} -- [P] [T1: 49,20] [112022] Parachute Platoon 55 A

    _2ND_1ST_PARACHUTE_COY_55_A_175 = {176,177,178} -- [C] [1102243] 2nd/1st Parachute Company 55 - A
    _1ST_PLT_176 = {176} -- [P] [T2: 47,20] [112022] Parachute Platoon 55 A
    _2ND_PLT_177 = {177} -- [P] [T2: 47,20] [112022] Parachute Platoon 55 A
    _3RD_PLT_178 = {178} -- [P] [T2: 47,20] [112022] Parachute Platoon 55 A

    _3RD_1ST_PARACHUTE_COY_55_A_179 = {180,181,182} -- [C] [1102243] 3rd/1st Parachute Company 55 - A
    _1ST_PLT_180 = {180} -- [P] [T2: 47,19] [112022] Parachute Platoon 55 A
    _2ND_PLT_181 = {181} -- [P] [T2: 47,19] [112022] Parachute Platoon 55 A
    _3RD_PLT_182 = {182} -- [P] [T2: 47,19] [112022] Parachute Platoon 55 A

    _1ST_PARACHUTE_WEAPONS_COY_55_183 = {184,185,187} -- [C] [1102245] 1st Parachute Weapons Company 55
    _ENGINEER_184 = {184} -- [P] [T1: 48,19] [112080] Parachute Engineer Platoon
    _MMG_185 = {185} -- [P] [T1: 48,19] [112077] Parachute M1919A4 Machine Gun
    _81MM_MORTAR_187 = {187} -- [P] [T1: 48,19] [111033] Parachute M1 81mm Mortars

    _5TH_PARACHUTE_BTN_55_A_441 = {442,462,444,445,446,448,449,450,452,453,454,456,457,459} -- [B] [1112228] 5th Parachute Battalion 55 - A

    _HQ_442 = {442} -- [P] [T4: 67,12] [113021] VNAF Airborne Battalion HQ (foot)

    _5TH_PARACHUTE_462 = {462} -- [P] [T4: 67,12] [114016] Airborne Commander 2

    _1ST_5TH_PARACHUTE_COY_55_A_443 = {444,445,446} -- [C] [1102243] 1st/5th Parachute Company 55 - A
    _1ST_PLT_444 = {444} -- [P] [T3: 66,12] [112022] Parachute Platoon 55 A
    _2ND_PLT_445 = {445} -- [P] [T3: 66,12] [112022] Parachute Platoon 55 A
    _3RD_PLT_446 = {446} -- [P] [T3: 66,12] [112022] Parachute Platoon 55 A

    _2ND_5TH_PARACHUTE_COY_55_A_447 = {448,449,450} -- [C] [1102243] 2nd/5th Parachute Company 55 - A
    _1ST_PLT_448 = {448} -- [P] [T3: 67,13] [112022] Parachute Platoon 55 A
    _2ND_PLT_449 = {449} -- [P] [T3: 67,13] [112022] Parachute Platoon 55 A
    _3RD_PLT_450 = {450} -- [P] [T3: 67,13] [112022] Parachute Platoon 55 A

    _3RD_5TH_PARACHUTE_COY_55_A_451 = {452,453,454} -- [C] [1102243] 3rd/5th Parachute Company 55 - A
    _1ST_PLT_452 = {452} -- [P] [T3: 67,11] [112022] Parachute Platoon 55 A
    _2ND_PLT_453 = {453} -- [P] [T3: 67,11] [112022] Parachute Platoon 55 A
    _3RD_PLT_454 = {454} -- [P] [T3: 67,11] [112022] Parachute Platoon 55 A

    _5TH_PARACHUTE_WEAPONS_COY_55_455 = {456,457,459} -- [C] [1102245] 5th Parachute Weapons Company 55
    _ENGINEER_456 = {456} -- [P] [T4: 66,11] [112080] Parachute Engineer Platoon
    _MMG_457 = {457} -- [P] [T4: 66,11] [112077] Parachute M1919A4 Machine Gun
    _81MM_MORTAR_459 = {459} -- [P] [T4: 66,11] [111033] Parachute M1 81mm Mortars

    _6TH_PARACHUTE_BTN_55_A_226 = {227,463,229,230,231,233,234,235,237,238,239,241,242,244} -- [B] [1112228] 6th Parachute Battalion 55 - A

    _HQ_227 = {227} -- [P] [T5: 72,12] [113021] VNAF Airborne Battalion HQ (foot)

    _6TH_PARACHUTE_463 = {463} -- [P] [T5: 72,12] [114016] Airborne Commander 2

    _1ST_6TH_PARACHUTE_COY_55_A_228 = {229,230,231} -- [C] [1102243] 1st/6th Parachute Company 55 - A
    _1ST_PLT_229 = {229} -- [P] [T4: 73,12] [112022] Parachute Platoon 55 A
    _2ND_PLT_230 = {230} -- [P] [T4: 73,12] [112022] Parachute Platoon 55 A
    _3RD_PLT_231 = {231} -- [P] [T4: 73,12] [112022] Parachute Platoon 55 A

    _2ND_6TH_PARACHUTE_COY_55_A_232 = {233,234,235} -- [C] [1102243] 2nd/6th Parachute Company 55 - A
    _1ST_PLT_233 = {233} -- [P] [T5: 72,12] [112022] Parachute Platoon 55 A
    _2ND_PLT_234 = {234} -- [P] [T5: 72,12] [112022] Parachute Platoon 55 A
    _3RD_PLT_235 = {235} -- [P] [T5: 72,12] [112022] Parachute Platoon 55 A

    _3RD_6TH_PARACHUTE_COY_55_A_236 = {237,238,239} -- [C] [1102243] 3rd/6th Parachute Company 55 - A
    _1ST_PLT_237 = {237} -- [P] [T4: 71,12] [112022] Parachute Platoon 55 A
    _2ND_PLT_238 = {238} -- [P] [T4: 71,12] [112022] Parachute Platoon 55 A
    _3RD_PLT_239 = {239} -- [P] [T4: 71,12] [112022] Parachute Platoon 55 A

    _6TH_PARACHUTE_WEAPONS_COY_55_240 = {241,242,244} -- [C] [1102245] 6th Parachute Weapons Company 55
    _ENGINEER_241 = {241} -- [P] [T5: 72,11] [112080] Parachute Engineer Platoon
    _MMG_242 = {242} -- [P] [T5: 72,11] [112077] Parachute M1919A4 Machine Gun
    _81MM_MORTAR_244 = {244} -- [P] [T5: 72,11] [111033] Parachute M1 81mm Mortars

    _NAVAL_ASSAULT_GROUPS_377 = {378,380,381,382,383,384,385,386,387,388,389,391,392,393,394,395,396,397,398,399,400,412} -- [B] [1112232] Naval Assault Groups

    _HQ_378 = {378} -- [P] [31,16] [113022] VNMC Battalion HQ (foot)

    _10TH_NAVAL_ASSAULT_GROUP_379 = {380,381,382,383,384,385,386,387,388,389} -- [C] [1102248] 10th Naval Assault Group
    _1ST_PLT_380 = {380} -- [P] [33,17] [112028] Marine Platoon 54 A
    _2ND_PLT_381 = {381} -- [P] [33,17] [112028] Marine Platoon 54 A
    _3RD_PLT_382 = {382} -- [P] [33,17] [112028] Marine Platoon 54 A
    _MMG_48_383 = {383} -- [P] [31,16] [112081] Marine M1919A6 Machine Gun
    _81MM_MORTARS_384 = {384} -- [P] [31,16] [111035] Marine M1 81mm Mortars
    _LCVP_385 = {385} -- [P] [33,17] [116808] Landing Craft Vehicle Personnel
    _LCVP_386 = {386} -- [P] [33,17] [116808] Landing Craft Vehicle Personnel
    _LCVP_387 = {387} -- [P] [33,17] [116808] Landing Craft Vehicle Personnel
    _LCA_388 = {388} -- [P] [31,16] [116812] Landing Craft Assault
    _LCA_389 = {389} -- [P] [31,16] [116812] Landing Craft Assault

    _11TH_NAVAL_ASSAULT_GROUP_390 = {391,392,393,394,395,396,397,398,399,400} -- [C] [1102248] 11th Naval Assault Group
    _1ST_PLT_391 = {391} -- [P] [36,19] [112028] Marine Platoon 54 A
    _2ND_PLT_392 = {392} -- [P] [38,20] [112028] Marine Platoon 54 A
    _3RD_PLT_393 = {393} -- [P] [36,19] [112028] Marine Platoon 54 A
    _MMG_48_394 = {394} -- [P] [36,19] [112081] Marine M1919A6 Machine Gun
    _81MM_MORTARS_395 = {395} -- [P] [38,20] [111035] Marine M1 81mm Mortars
    _LCVP_396 = {396} -- [P] [36,19] [116808] Landing Craft Vehicle Personnel
    _LCVP_397 = {397} -- [P] [38,20] [116808] Landing Craft Vehicle Personnel
    _LCVP_398 = {398} -- [P] [36,19] [116808] Landing Craft Vehicle Personnel
    _LCA_399 = {399} -- [P] [36,19] [116812] Landing Craft Assault
    _LCA_400 = {400} -- [P] [38,20] [116812] Landing Craft Assault

    _LCP_412 = {412} -- [P] [31,16] [116805] Landing Craft Personnel

    _3RD_ARTILLERY_BTN_55_105MM_413 = {414,416,417,421,422,426,427,432,433,434,435,430} -- [B] [1111205] 3rd Artillery Battalion 55 - 105mm

    _HQ_414 = {414} -- [P] [T999: 46,0] [113010] ARVN Battalion HQ (foot)

    _1ST_3RD_HOWITZER_BTY_55_105MMX4_415 = {416,417} -- [C] [1101204] 1st/3rd Howitzer Battery 55 - 105mmx4
    _HOWITZER_BTY_416 = {416} -- [P] [T999: 46,0] [111022] M101 105mm Howitzers
    _M35_417 = {417} -- [P] [T999: 46,0] [117039] M35 2 1/2 ton truck

    _2ND_3RD_HOWITZER_BTY_55_105MMX4_420 = {421,422} -- [C] [1101204] 2nd/3rd Howitzer Battery 55 - 105mmx4
    _HOWITZER_BTY_421 = {421} -- [P] [T999: 46,0] [111022] M101 105mm Howitzers
    _M35_422 = {422} -- [P] [T999: 46,0] [117039] M35 2 1/2 ton truck

    _3RD_3RD_HOWITZER_BTY_55_105MMX4_425 = {426,427} -- [C] [1101204] 3rd/3rd Howitzer Battery 55 - 105mmx4
    _HOWITZER_BTY_426 = {426} -- [P] [T999: 46,0] [111022] M101 105mm Howitzers
    _M35_427 = {427} -- [P] [T999: 46,0] [117039] M35 2 1/2 ton truck

    _1ST_34TH_HOWITZER_BTY_55_105MMX4_0VP_431 = {432,433,434,435} -- [C] [1101204] 1st/34th Howitzer Battery 55 - 105mmx4 - 0VP
    _HOWITZER_BTY_432 = {432} -- [P] [T998: 46,0] [111022] M101 105mm Howitzers
    _M35_433 = {433} -- [P] [T998: 46,0] [117039] M35 2 1/2 ton truck
    _MMG_48_434 = {434} -- [P] [T998: 46,0] [112071] M1919A4 Machine Gun
    _MB_M38_435 = {435} -- [P] [T998: 46,0] [117027] MB/M38 1/4 ton truck

    _M37_430 = {430} -- [P] [T999: 46,0] [117023] M37 3/4 ton truck

    _LIAISON_SQUADRON_55_O1_436 = {437,438,439,440} -- [C] [1107201] Liaison Squadron 55 - O-1
    _O1_437 = {437} -- [P] [T4: 15,0] [116502] Cessna O-1 Birddog
    _O1_438 = {438} -- [P] [T6: 13,0] [116502] Cessna O-1 Birddog
    _O1_439 = {439} -- [P] [T2: 17,0] [116502] Cessna O-1 Birddog
    _O1_440 = {440} -- [P] [T7: 11,0] [116502] Cessna O-1 Birddog

    _LOGISTIC_55_LEVEL_2_263 = {266} -- [C] [1109207] Logistic 55 - Level 2

    _SUPPLY_TRUCKS_266 = {266} -- [P] [T997: 46,0] [117033] Supply Trucks (VP)

    _M35_267 = {267} -- [P] [T998: 46,0] [117040] M35 2 1/2 ton truck

    _GRUMMAN_F8F_BEARCAT_ROCKETS_503 = {503} -- [P] [9999,9999] [115001] Grumman F8F Bearcat {Rockets}

    _GRUMMAN_F8F_BEARCAT_ROCKETS_504 = {504} -- [P] [9999,9999] [115001] Grumman F8F Bearcat {Rockets}

    _GRUMMAN_F8F_BEARCAT_ROCKETS_505 = {505} -- [P] [9999,9999] [115001] Grumman F8F Bearcat {Rockets}

    _GRUMMAN_F8F_BEARCAT_ROCKETS_506 = {506} -- [P] [9999,9999] [115001] Grumman F8F Bearcat {Rockets}

    _GRUMMAN_F8F_BEARCAT_ROCKETS_507 = {507} -- [P] [9999,9999] [115001] Grumman F8F Bearcat {Rockets}

    _GRUMMAN_F8F_BEARCAT_ROCKETS_508 = {508} -- [P] [9999,9999] [115001] Grumman F8F Bearcat {Rockets}

    _DOUGLAS_B26_INVADER_BOMBS_509 = {509} -- [P] [9999,9999] [115012] Douglas B-26 Invader {Bombs}

    _DOUGLAS_B26_INVADER_BOMBS_510 = {510} -- [P] [9999,9999] [115012] Douglas B-26 Invader {Bombs}

    _DOUGLAS_B26_INVADER_BOMBS_511 = {511} -- [P] [9999,9999] [115012] Douglas B-26 Invader {Bombs}

    _DOUGLAS_B26_INVADER_BOMBS_512 = {512} -- [P] [9999,9999] [115012] Douglas B-26 Invader {Bombs}

    _DOUGLAS_B26_INVADER_BOMBS_513 = {513} -- [P] [9999,9999] [115012] Douglas B-26 Invader {Bombs}

    _DOUGLAS_B26_INVADER_BOMBS_514 = {514} -- [P] [9999,9999] [115012] Douglas B-26 Invader {Bombs}

    _DOUGLAS_B26_INVADER_BOMBS_515 = {515} -- [P] [9999,9999] [115012] Douglas B-26 Invader {Bombs}

    _DOUGLAS_B26_INVADER_BOMBS_516 = {516} -- [P] [9999,9999] [115012] Douglas B-26 Invader {Bombs}

    -- hand-crafted org lists, if any, to follow

    --traceoff()

end

------------------------------------------------------------------------------------------------------------------------

function init_variables ()

    -- initialize values possibly varying through the course of the scenario
    -- called once only, in on_startup()

    -- embark/disembark points
    -- for example:
    -- _D303_VC_MAIN_FORCE_INF_BTN_2ND_RIFLE_COY_EMBARK_PT = random_index(3,5)

    -- target points
    -- for example:
    -- _MACV_GUNSHIPS_TARGET_PT = random_pick({1,2,3,4,5,6,7,8,12})

    -- others ...
    -- for example:
    -- NUMBER_VC_ATTACKS = 0
    -- _2ND_ARVN_MARINE_BTN_LEADERLESS = false
    -- NUMBER_US_AIRSTRIKES = air_support("a")
    -- BATTLE_PLAN_HMONG = dieroll(2)

    VNA_LOSS_RATE_TRIGGER = random_index(65,75) -- random integer from 65 thru 75

    -- logistic defense assignments

    _C1_1ST_1ST_RIFLE_COY_48_US_6_POST = random_pick({146, 490}) -- _SUPPLY_CACHE_146, _JUNGLE_FACTORY_490
    _C3_1ST_1ST_RIFLE_COY_48_US_16_POST = random_pick({148, 148, 148, UNKNOWN}) -- _SUPPLY_CACHE_148
    if _C3_1ST_1ST_RIFLE_COY_48_US_16_POST == 148 then
        _C2_1ST_1ST_RIFLE_COY_48_US_11_POST = UNKNOWN
    else
        _C2_1ST_1ST_RIFLE_COY_48_US_11_POST = 148 -- _SUPPLY_CACHE_148
    end

    _C1_1ST_2ND_RIFLE_COY_48_US_37_POST = random_pick({"71,37", HEXUNKNOWN, HEXUNKNOWN, HEXUNKNOWN}) -- nothing at "71,37"
    _C2_1ST_2ND_RIFLE_COY_48_US_42_POST = random_pick({147, 488}) -- _SUPPLY_CACHE_147, _JUNGLE_FACTORY_488
    _C3_1ST_2ND_RIFLE_COY_48_US_47_POST = random_pick({"91,50", OBJECTIVES[28], OBJECTIVES[32]}) -- _SUPPLY_DEPOT_486 at "91,50"
    
    _C2_1ST_5TH_RIFLE_COY_48_US_73_POST = random_pick({149, UNKNOWN}) -- _JUNGLE_FACTORY_149

end

------------------------------------------------------------------------------------------------------------------------

function show_briefing (side) -- DO NOT REMOVE

    -- player briefings

    if side == SIDE_A then

            dialog("SMEAC", 
                   "Battle of Rung Sat\n" ..
                   "\n" ..
                   "\n" .. 
                   "SITUATION:\n" ..
                   "\n" ..
                   "In order to cease the attacks on shipping in the Rung Sat area, Operation HOANG DIEU has been organized and set in motion to deal with the Binh Xuen army once and for all!\n" ..
                   "\n" ..
                   "Friendly Forces: Elements of the 154th Infantry Regiment with support from Marine Naval Assault Groups and Parachute battalions.\n" ..
                   "\n" ..
                   "Enemy Forces: The scattered remnants of the Binh Xuen army are reported to be in the area.\n" ..
                   "\n" ..
                   "\n" .. 
                   "MISSION:\n" ..
                   "\n" ..
                   "Your Primary Mission is to clear the entire area of operations, defeating any Binh Xuen forces that are found.\n" ..
                   "\n" ..
                   "Your Secondary Mission is to destroy any headquarters and supplies found.\n" ..
                   "\n" ..
                   "\n" .. 
                   "EXECUTION:\n" ..
                   "\n" ..
                   "Use the 154th Infantry battalions and Marine Naval Groups to clear the villages and military posts from the main islands. Utilize the naval transports when available to transport between them.\n" ..
                   "\n" ..
                   "The parachute battalions will land on the northern operating area, use them to cut off the escape routes and search all the areas north of Song Dong Tranh.\n" ..
                   "\n" ..
                   "\n" .. 
                   "POLITICAL:\n" ..
                   "\n" ..
--                 " No special political considerations.\n\n" ..
                   "You lose Event Points for indirect firing or ordering airstrikes on inhabited hexes (village, city, suburb), whether or not occupied by the enemy.\n" ..
                   "\n" ..
                   "\n" ..
                   "ADMIN:\n" ..
                   "\n" ..
                   "The supply levels are high at the beginning of the scenario, but expect them to taper off as the operation proceeds.\n" ..
                   "\n" ..
                   "\n" .. 
                   "COMMAND AND CONTROL:\n" ..
                   "\n" ..
                   "Weather during the day will be mostly clear with visibility lightly varying as the operation unfolds.",
                   side, side
                  )

    elseif side == SIDE_B then

            dialog("Side B Briefing", 
                   "Battle of Rung Sat\n" ..
                   "\n" ..
                   "\n" .. 
                   "SITUATION:\n" ..
                   "\n" ..
                   "Intelligence reports that a large operation is underway and the Government forces are going to coming into the area.\n" ..
                   "\n" ..
                   "Friendly Forces: The remnants of the Binh Xuan army consisting of scattered infantry companie with some heavy weapons\n" ..
                   "\n" ..
                   "Enemy Forces: Various elements of the ARVN Infantry, Parachute and Marine forces are operating in the area\n" ..
                   "\n" ..
                   "\n" .. 
                   "MISSION:\n" ..
                   "\n" ..
                   "Your Primary Mission is to delay the attacks, making it impossible for the ARVN to complete their mission.\n" ..
                   "\n" ..
                   "Your Secondary Mission is to protect the headquarters and supply units so we can fight again in the future!\n" ..
                   "\n" ..
                   "\n" .. 
                   "EXECUTION:\n" ..
                   "\n" ..
                   "Use your companies to peform a fighting withdrawal. Counterattack to through off the attackers when possible.\n" ..
                   "\n" ..
                   "There are a number of junks and boats to help ferry your units around to move them to the best locations possible.\n" ..
                   "\n" ..
                   "\n" .. 
                   "POLITICAL:\n" ..
                   "\n" ..
--                 " No special political considerations.\n\n" ..
                   "You lose Event Points for indirect firing or ordering airstrikes on inhabited hexes (village, city, suburb), whether or not occupied by the enemy.\n" ..
                   "\n" ..
                   "\n" ..
                   "ADMIN:\n" ..
                   "\n" ..
                   "The supply levels are high at the beginning of the scenario, but expect them to taper off as the operation proceeds.\n" ..
                   "\n" ..
                   "\n" .. 
                   "COMMAND AND CONTROL:\n" ..
                   "\n" ..
                   "Weather during the day will be mostly clear with visibility lightly varying as the operation unfolds.",
                   side, side
                  )

    end

end

------------------------------------------------------------------------------------------------------------------------

function on_shutdown () -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------
    
function on_next_turn (turn) -- DO NOT REMOVE
    
    -- after first (in)direct fire, Side A loses (arty) supply each turn
    if SIDE_A_FIRED then
        inc_ammo_level(SIDE_A, -2)
    end
    if SIDE_A_ARTY_FIRED then
        inc_arty_ammo_level(SIDE_A, -2)
    end

    -- after first (in)direct fire, Side B loses (arty) supply each turn
    if SIDE_B_FIRED then
        inc_ammo_level(SIDE_B, -2)
    end
    if SIDE_B_ARTY_FIRED then
        inc_arty_ammo_level(SIDE_B, -2)
    end

    if turn == 1 then
        allot_airstrikes(UNKNOWN, VNA_SIDE, 0, 0, 0)
    end
    if turn == 18 then
        allot_airstrikes(18, VNA_SIDE, dieroll(3)-1, 3, 14, "", "Some air support is now on station and ready to assist in your operation!")
    elseif turn >= 19 then
        allot_airstrikes(UNKNOWN, VNA_SIDE, random_pick({0,0,1,1,1,1,2,2,2}), 3)
    end

    -- BX gain 100 EP for holding OBJECTIVES[13] until Turn 8
    if turn == 8 then
        if not OBJECTIVES13_CAPTURED then -- see on_objective_capture()
            inc_event_points(BX_SIDE, 100)
        end
    end

    -- BX gain 100 EP for holding OBJECTIVES[21] until Turn 30
    if turn == 30 then
        if not OBJECTIVES21_CAPTURED then -- see on_objective_capture()
            inc_event_points(BX_SIDE, 100)
        end
    end

end

------------------------------------------------------------------------------------------------------------------------

function on_next_phase (turn, side) -- DO NOT REMOVE

    -- for testing purposes; note that these might override player selected options!
    -- by default, in normal game play, the player selected options apply;
    -- by default, in auto-test mode, FOW is OFF, all the time, for both sides
    if is_test_trial_play() and not is_qa_testing() then
        set_fow(side, 0) -- for current side, set FOW OFF
        set_fow(other_side(side), 1) -- for opposing side, set FOW ON
    end

    set_org_lists(turn, side)

    if turn == 1 then
        show_briefing(side)
    end

    battle_plan(turn, side)

--[[ commonly used, uncomment and adapt as necessary:
    -- every phase, adjust downward the NVA assault_attack_aggressiveness_effect bonus per their current loss rate
    adjust_adaptive_ai (sideof(NORTH_VIETNAM_NATION), NORTH_VIETNAM_NATION, "assault_attack_aggressiveness_effect", - math.floor(total_loss_rate(sideof(NORTH_VIETNAM_NATION))/2))
--]]

    csee_check(turn, side) -- DO NOT MOVE, OR REMOVE

end

------------------------------------------------------------------------------------------------------------------------

function battle_plan (turn, side)

    -- UNLEASH is true if game launched with -U switch, or if Ctrl+Alt+U in game
    -- Ctrl+Alt+U is a toggle, so will set UNLEASH to false after an earlier Ctrl+Alt+U (setting UNLEASH to true)
    if UNLEASH then
        unleash(ALLA)
        unleash(ALLB)
        return
    end

    if side == SIDE_A and is_ai(side) then

        --traceon()
        battle_plan_a(turn, side)
        --traceoff()

    elseif side == SIDE_B and is_ai(side) then

        --traceon()
        battle_plan_b(turn, side)
        --traceoff()

    end

end

------------------------------------------------------------------------------------------------------------------------

function battle_plan_a (turn, side)

    -- standard orders, uncomment as necessary:
    if turn == 1 then
        -- all Side A units halt initially (or maybe use hold())
        halt(ALLA)
    end

    -------------------------------------------------------
    -- _OPERATION_HOANG_DIEU_167 -- Operation Hoang Dieu --
    -------------------------------------------------------

    -- _VNA_HQ_460 -- VNA Brigade HQ (foot)
    do local units = _VNA_HQ_460

    end

    -- _AIRBORNE_HQ_168 -- VNAF Airborne Brigade HQ (foot)
    do local units = _AIRBORNE_HQ_168
        -- see _5TH_PARACHUTE_BTN_55_A_441 orders
    end

    ---------------------------------------------------------------
    -- _154TH_INF_RGT_55_B_268 -- 154th Infantry Regiment 55 - B --
    ---------------------------------------------------------------

    --------------------------------------------------------------------------
    -- _22ND_154TH_INF_BTN_55_B_270 -- 22nd/154th Infantry Battalion 55 - B --
    --------------------------------------------------------------------------

    -- _HQ_271 -- ARVN Battalion HQ (foot)
    do local units = _HQ_271

    end

    -- _22ND_154TH_464 -- ARVN Commander 1
    do local units = _22ND_154TH_464

    end

    -- _1ST_22ND_INF_COY_55_B_272 -- 1st/22nd Infantry Company 55 - B
    do local units = _1ST_22ND_INF_COY_55_B_272

    end

    -- _2ND_22ND_INF_COY_55_B_278 -- 2nd/22nd Infantry Company 55 - B
    do local units = _2ND_22ND_INF_COY_55_B_278

    end

    -- _3RD_22ND_INF_COY_55_B_284 -- 3rd/22nd Infantry Company 55 - B
    do local units = _3RD_22ND_INF_COY_55_B_284

    end

    -- _22NDWEAPONS_COY_55_296 -- 22ndWeapons Company 55
    do local units = _22NDWEAPONS_COY_55_296

    end
    -- _81MM_MORTAR_300 -- M1 81mm Mortars

    --------------------------------------------------------------------------
    -- _58TH_154TH_INF_BTN_55_B_301 -- 58th/154th Infantry Battalion 55 - B --
    --------------------------------------------------------------------------

    -- _HQ_302 -- ARVN Battalion HQ (foot)
    do local units = _HQ_302

    end

    -- _58TH_154TH_465 -- ARVN Commander 1
    do local units = _58TH_154TH_465

    end

    -- _1ST_58TH_INF_COY_55_B_303 -- 1st/58th Infantry Company 55 - B
    do local units = _1ST_58TH_INF_COY_55_B_303

    end

    -- _2ND_58TH_INF_COY_55_B_309 -- 2nd/58th Infantry Company 55 - B
    do local units = _2ND_58TH_INF_COY_55_B_309

    end

    -- _3RD_58TH_INF_COY_55_B_315 -- 3rd/58th Infantry Company 55 - B
    do local units = _3RD_58TH_INF_COY_55_B_315

    end

    -- _58TH_WEAPONS_COY_55_327 -- 58th Weapons Company 55
    do local units = _58TH_WEAPONS_COY_55_327

    end
    -- _81MM_MORTAR_331 -- M1 81mm Mortars

    -------------------------------------------------------------------
    -- _1ST_PARACHUTE_BTN_55_A_169 -- 1st Parachute Battalion 55 - A --
    -------------------------------------------------------------------

    -- _HQ_170 -- VNAF Airborne Battalion HQ (foot)
    -- _1ST_PARACHUTE_461 -- Airborne Commander 2
    do local units = join({_HQ_170, _1ST_PARACHUTE_461})
        if _1ST_1ST_PARACHUTE_COY_55_A_171_READY and _2ND_1ST_PARACHUTE_COY_55_A_175_READY and _3RD_1ST_PARACHUTE_COY_55_A_179_READY then
            move_way_point(units, {"50,21", "52,23"})
            if objective_owner(OBJECTIVES[10]) == VNA_SIDE then
                defend_way_point(units, {"51,25", "52,27", OBJECTIVES[10]}, NODIR, 1, 100, DEFEND_NORMAL)
            elseif objective_owner(OBJECTIVES[9]) == VNA_SIDE then
                defend_normal(units, OBJECTIVES[9], NODIR, 0, 100)
            end
        end
    end
    do local units = _1ST_PARACHUTE_461
        -- no special orders, stay with HQ
    end

    -- _1ST_1ST_PARACHUTE_COY_55_A_171 -- 1st/1st Parachute Company 55 - A
    do local units = _1ST_1ST_PARACHUTE_COY_55_A_171
        _1ST_1ST_PARACHUTE_COY_55_A_171_READY = _1ST_1ST_PARACHUTE_COY_55_A_171_READY or ready(units)
        if _1ST_1ST_PARACHUTE_COY_55_A_171_READY then
            if objective_owner(OBJECTIVES[9]) == BX_SIDE then
                attack_way_point(units, {"50,21", "52,23", OBJECTIVES[9]}, NODIR, 0, 100, ATTACK_STRONG)
            elseif objective_owner(OBJECTIVES[10]) == BX_SIDE then
                attack_way_point(units, {"52,27", OBJECTIVES[10]}, NODIR, 0, 100, ATTACK_STRONG)
--            ...
            end
            if loss_rate(units) >= VNA_LOSS_RATE_TRIGGER then
                _1ST_1ST_PARACHUTE_COY_55_A_171_RETIRE_PT = _1ST_1ST_PARACHUTE_COY_55_A_171_RETIRE_PT or retire_point(units)
                defend_weak(units, _1ST_1ST_PARACHUTE_COY_55_A_171_RETIRE_PT, NODIR, 1)
            end
        end
    end

    -- _2ND_1ST_PARACHUTE_COY_55_A_175 -- 2nd/1st Parachute Company 55 - A
    do local units = _2ND_1ST_PARACHUTE_COY_55_A_175
        _2ND_1ST_PARACHUTE_COY_55_A_175_READY = _2ND_1ST_PARACHUTE_COY_55_A_175_READY or ready(units)
        if _2ND_1ST_PARACHUTE_COY_55_A_175_READY then
            if objective_owner(OBJECTIVES[9]) == BX_SIDE then
                attack_way_point(units, {"50,21", "52,23", OBJECTIVES[9]}, NODIR, 0, 100, ATTACK_STRONG)
            elseif objective_owner(OBJECTIVES[10]) == BX_SIDE then
                attack_way_point(units, {"52,27", OBJECTIVES[10]}, NODIR, 0, 100, ATTACK_STRONG)
--            ...
            end
            if loss_rate(units) >= VNA_LOSS_RATE_TRIGGER then
                _2ND_1ST_PARACHUTE_COY_55_A_175_RETIRE_PT = _2ND_1ST_PARACHUTE_COY_55_A_175_RETIRE_PT or retire_point(units)
                defend_weak(units, _2ND_1ST_PARACHUTE_COY_55_A_175_RETIRE_PT, NODIR, 1)
            end
        end
    end

    -- _3RD_1ST_PARACHUTE_COY_55_A_179 -- 3rd/1st Parachute Company 55 - A
    do local units = _3RD_1ST_PARACHUTE_COY_55_A_179
        _3RD_1ST_PARACHUTE_COY_55_A_179_READY = _3RD_1ST_PARACHUTE_COY_55_A_179_READY or ready(units)
        if _3RD_1ST_PARACHUTE_COY_55_A_179_READY then
            if objective_owner(OBJECTIVES[9]) == BX_SIDE then
                attack_way_point(units, {"50,21", "52,23", OBJECTIVES[9]}, NODIR, 0, 100, ATTACK_STRONG)
            elseif objective_owner(OBJECTIVES[10]) == BX_SIDE then
                attack_way_point(units, {"52,27", OBJECTIVES[10]}, NODIR, 0, 100, ATTACK_STRONG)
--            ...
            end
            if loss_rate(units) >= VNA_LOSS_RATE_TRIGGER then
                _3RD_1ST_PARACHUTE_COY_55_A_179_RETIRE_PT = _3RD_1ST_PARACHUTE_COY_55_A_179_RETIRE_PT or retire_point(units)
                defend_weak(units, _3RD_1ST_PARACHUTE_COY_55_A_179_RETIRE_PT, NODIR, 1)
            end
        end
    end

    -- _1ST_PARACHUTE_WEAPONS_COY_55_183 -- 1st Parachute Weapons Company 55
    do local units = _1ST_PARACHUTE_WEAPONS_COY_55_183
        _1ST_PARACHUTE_WEAPONS_COY_55_183_READY = _1ST_PARACHUTE_WEAPONS_COY_55_183_READY or ready(units)
        if _1ST_PARACHUTE_WEAPONS_COY_55_183_READY then
            if objective_owner(OBJECTIVES[9]) == BX_SIDE then
                attack_way_point(units, {"50,21", "52,23", OBJECTIVES[9]}, NODIR, 0, 100, ATTACK_STRONG)
            elseif objective_owner(OBJECTIVES[10]) == BX_SIDE then
                attack_way_point(units, {"52,27", OBJECTIVES[10]}, NODIR, 0, 100, ATTACK_STRONG)
--            ...
            end
            if loss_rate(units) >= VNA_LOSS_RATE_TRIGGER then
                _1ST_PARACHUTE_WEAPONS_COY_55_183_RETIRE_PT = _1ST_PARACHUTE_WEAPONS_COY_55_183_RETIRE_PT or retire_point(units)
                defend_weak(units, _1ST_PARACHUTE_WEAPONS_COY_55_183_RETIRE_PT, NODIR, 1)
            end
        end
    end
    -- _81MM_MORTAR_187 -- Parachute M1 81mm Mortars
    if objective_owner(OBJECTIVES[10]) == VNA_SIDE then
        if not at(_81MM_MORTAR_187, OBJECTIVES[10]) then
            move_norush(_81MM_MORTAR_187, OBJECTIVES[10])
        else
            fire_indirect_nearest(_81MM_MORTAR_187, 100)
        end
    end

    do local units = join({_1ST_1ST_PARACHUTE_COY_55_A_171, _2ND_1ST_PARACHUTE_COY_55_A_175, _3RD_1ST_PARACHUTE_COY_55_A_179})
        if objective_owner(OBJECTIVES[9]) == VNA_SIDE then
            -- have the weakest unit among the 1st/1st, 2nd/1st & 3rd/1st join in garrisoning and defending OBJECTIVES[9]
            _VNA_OBJECTIVES9_GARRISON = _VNA_OBJECTIVES9_GARRISON or random_pick(counters_weakest(units))
            defend_normal(_VNA_OBJECTIVES9_GARRISON, OBJECTIVES[9], NODIR, 0, 100)
            if objective_owner(OBJECTIVES[10]) == VNA_SIDE then
                -- have the second weakest unit among the 1st/1st, 2nd/1st & 3rd/1st join in garrisoning and defending OBJECTIVES[10]
                _VNA_OBJECTIVES10_GARRISON = _VNA_OBJECTIVES10_GARRISON or random_pick(counters_weakest(difference(units,_VNA_OBJECTIVES9_GARRISON)))
                defend_normal(_VNA_OBJECTIVES10_GARRISON, OBJECTIVES[10], NODIR, 0, 100)
            end
        end
    end

    -------------------------------------------------------------------
    -- _5TH_PARACHUTE_BTN_55_A_441 -- 5th Parachute Battalion 55 - A --
    -------------------------------------------------------------------

    local obj13_threatened = (units_within_count(OBJECTIVES[13], NODIR, 3, BX_SIDE) > 0)

    -- _HQ_442 -- VNAF Airborne Battalion HQ (foot)
    -- _5TH_PARACHUTE_462 -- Airborne Commander 2
    do local units = join({_AIRBORNE_HQ_168, _HQ_442, _5TH_PARACHUTE_462})
        if (_1ST_5TH_PARACHUTE_COY_55_A_443_READY or
            _2ND_5TH_PARACHUTE_COY_55_A_447_READY or
            _3RD_5TH_PARACHUTE_COY_55_A_451_READY) and
           (_1ST_6TH_PARACHUTE_COY_55_A_228_READY or
            _2ND_6TH_PARACHUTE_COY_55_A_232_READY or
            _3RD_6TH_PARACHUTE_COY_55_A_236_READY) then
            move_norush(units, OBJECTIVES[15], NODIR, 0, 100)
            if within(units, OBJECTIVES[15], NODIR, 1) then
                defend_weak(units, OBJECTIVES[15], NODIR, 0)
            end
            -- see below also _MMG_457, which joins in the defense of OBJECTIVES[15]
        end
    end

    -- _1ST_5TH_PARACHUTE_COY_55_A_443 -- 1st/5th Parachute Company 55 - A
    do local units = _1ST_5TH_PARACHUTE_COY_55_A_443
        _1ST_5TH_PARACHUTE_COY_55_A_443_READY = _1ST_5TH_PARACHUTE_COY_55_A_443_READY or ready(units)
        if _1ST_5TH_PARACHUTE_COY_55_A_443_READY then
            if not attack_sequential(units, {OBJECTIVES[13], OBJECTIVES[8]}, {ATTACK_STRONG, ATTACK_STRONG}, {true, true}) then
                defend_normal(units, OBJECTIVES[8])
            end
            if loss_rate(units) >= VNA_LOSS_RATE_TRIGGER then
               _1ST_5TH_PARACHUTE_COY_55_A_443_RETIRE_PT = _1ST_5TH_PARACHUTE_COY_55_A_443_RETIRE_PT or retire_point(units)
                defend_weak(units, _1ST_5TH_PARACHUTE_COY_55_A_443_RETIRE_PT, NODIR, 1)
            end
        end
    end

    -- _2ND_5TH_PARACHUTE_COY_55_A_447 -- 2nd/5th Parachute Company 55 - A
    do local units = _2ND_5TH_PARACHUTE_COY_55_A_447
        _2ND_5TH_PARACHUTE_COY_55_A_447_READY = _2ND_5TH_PARACHUTE_COY_55_A_447_READY or ready(units)
        if _2ND_5TH_PARACHUTE_COY_55_A_447_READY then
            if obj13_threatened and
               not _2ND_5TH_PARACHUTE_COY_55_A_447_ORDER then
                attack_nearest_to_hex(units, OBJECTIVES[13], NODIR, 1, 100, ATTACK_STRONG)
            else
                _2ND_5TH_PARACHUTE_COY_55_A_447_ORDER = _2ND_5TH_PARACHUTE_COY_55_A_447_ORDER or random_pick({1,1,2})
                if _2ND_5TH_PARACHUTE_COY_55_A_447_ORDER == 1 then
                    if not attack_sequential(units, {OBJECTIVES[16], OBJECTIVES[17]}, ATTACK_STRONG, true) then
                        defend_normal(units, OBJECTIVES[13])
                    end
                elseif _2ND_5TH_PARACHUTE_COY_55_A_447_ORDER == 2 then
                    defend_normal(units, OBJECTIVES[13], NODIR, 1)
                end
            end
            if loss_rate(units) >= VNA_LOSS_RATE_TRIGGER then
                _2ND_5TH_PARACHUTE_COY_55_A_447_RETIRE_PT = _2ND_5TH_PARACHUTE_COY_55_A_447_RETIRE_PT or retire_point(units)
                defend_weak(units, _2ND_5TH_PARACHUTE_COY_55_A_447_RETIRE_PT, NODIR, 1)
            end
        end
    end

    if objective_owner(OBJECTIVES[13]) == VNA_SIDE then
        -- if 2/5 not assigned to defend OBJECTIVES[13]
        if _2ND_5TH_PARACHUTE_COY_55_A_447_ORDER and
           _2ND_5TH_PARACHUTE_COY_55_A_447_ORDER ~= 2 then
            -- assign the weakest unit among 2/5 to garrison and normal defend OBJECTIVES[13]
            _VNA_OBJECTIVES13_GARRISON = _VNA_OBJECTIVES13_GARRISON or random_pick(counters_weakest(_2ND_5TH_PARACHUTE_COY_55_A_447))
            defend_normal(_VNA_OBJECTIVES13_GARRISON, OBJECTIVES[13], NODIR, 0, 100)
     -- else _2ND_5TH_PARACHUTE_COY_55_A_447_ORDER is 2, and that company as a whole is defending OBJECTIVES[13]
        end
    end

    -- _3RD_5TH_PARACHUTE_COY_55_A_451 -- 3rd/5th Parachute Company 55 - A
    do local units = _3RD_5TH_PARACHUTE_COY_55_A_451
        _3RD_5TH_PARACHUTE_COY_55_A_451_READY = _3RD_5TH_PARACHUTE_COY_55_A_451_READY or ready(units)
        if _3RD_5TH_PARACHUTE_COY_55_A_451_READY then
            if not _3RD_5TH_PARACHUTE_COY_5TH_PARACHUTE_WEAPONS_COY_ORDER and
               objective_owner(OBJECTIVES[13]) == BX_SIDE then
                attack_strong(units, OBJECTIVES[13], NODIR, 1, 100)
            else
                _3RD_5TH_PARACHUTE_COY_5TH_PARACHUTE_WEAPONS_COY_ORDER = _3RD_5TH_PARACHUTE_COY_5TH_PARACHUTE_WEAPONS_COY_ORDER or 1
                if not attack_sequential(units, {OBJECTIVES[16], OBJECTIVES[17]}, ATTACK_STRONG, true) then
                    defend_normal(units, OBJECTIVES[17])
                end
            end
            if loss_rate(units) >= VNA_LOSS_RATE_TRIGGER then
                _3RD_5TH_PARACHUTE_COY_55_A_451_RETIRE_PT = _3RD_5TH_PARACHUTE_COY_55_A_451_RETIRE_PT or retire_point(units)
                defend_weak(units, _3RD_5TH_PARACHUTE_COY_55_A_451_RETIRE_PT, NODIR, 1)
            end
        end
    end

    -- _5TH_PARACHUTE_WEAPONS_COY_55_455 -- 5th Parachute Weapons Company 55
    do local units = _5TH_PARACHUTE_WEAPONS_COY_55_455
        _5TH_PARACHUTE_WEAPONS_COY_55_455_READY = _5TH_PARACHUTE_WEAPONS_COY_55_455_READY or ready(units)
        if _5TH_PARACHUTE_WEAPONS_COY_55_455_READY then
            if not _3RD_5TH_PARACHUTE_COY_5TH_PARACHUTE_WEAPONS_COY_ORDER and
               objective_owner(OBJECTIVES[13]) == BX_SIDE then
                attack_strong(units, OBJECTIVES[13], NODIR, 1, 100)
            else
                _3RD_5TH_PARACHUTE_COY_5TH_PARACHUTE_WEAPONS_COY_ORDER = _3RD_5TH_PARACHUTE_COY_5TH_PARACHUTE_WEAPONS_COY_ORDER or 1
                if not attack_sequential(units, {OBJECTIVES[16], OBJECTIVES[17]}, ATTACK_STRONG, true) then
                    defend_normal(units, OBJECTIVES[16])
                end
                -- _MMG_457
                -- strong defend the _AIRBORNE_HQ_168 at OBJECTIVES[15]
                defend_strong(_MMG_457, OBJECTIVES[15])
                -- _81MM_MORTAR_459 -- Parachute M1 81mm Mortars
                if not _3RD_5TH_PARACHUTE_COY_5TH_PARACHUTE_WEAPONS_COY_ORDER and
                   obj13_threatened then
                    fire_indirect_nearest_to_hex(_81MM_MORTAR_459, OBJECTIVES[13], 100)
                else
                    if owned(OBJECTIVES[16], BX_SIDE) and
                       not at(_81MM_MORTAR_459, "69,5") then
                        move_way_point(_81MM_MORTAR_459, {"67,7", "69,5"}, NODIR, 0, 100)
                    elseif owned(OBJECTIVES[16], VNA_SIDE) and
                           not at (_81MM_MORTAR_459, OBJECTIVES[16]) then
                        move_rush(_81MM_MORTAR_459, OBJECTIVES[16])
                    else
                        fire_indirect_nearest_to_hex(_81MM_MORTAR_459, "71,3", 100)
                    end
                end
            end
            if loss_rate(units) >= VNA_LOSS_RATE_TRIGGER then
                _5TH_PARACHUTE_WEAPONS_COY_55_455_RETIRE_PT =_5TH_PARACHUTE_WEAPONS_COY_55_455_RETIRE_PT or retire_point(units)
                defend_weak(units, _5TH_PARACHUTE_WEAPONS_COY_55_455_RETIRE_PT, NODIR, 1)
            end
        end
    end

    -------------------------------------------------------------------
    -- _6TH_PARACHUTE_BTN_55_A_226 -- 6th Parachute Battalion 55 - A --
    -------------------------------------------------------------------

    local obj24_threatened = (units_within_count(OBJECTIVES[24], NODIR, 3, BX_SIDE) > 0)
    local obj25_threatened = (units_within_count(OBJECTIVES[25], NODIR, 3, BX_SIDE) > 0)
    local obj27_threatened = (units_within_count(OBJECTIVES[27], NODIR, 3, BX_SIDE) > 0)

    if DEBUG then log(APPLOG, LOG_DEBUG,
        "at turn " .. current_turn() ..
        ", obj24_threatened " .. ((obj24_threatened and "true") or "false") ..
        ", obj25_threatened " .. ((obj25_threatened and "true") or "false") ..
        ", obj27_threatened " .. ((obj27_threatened and "true") or "false"))
    end

    -- _HQ_227 -- VNAF Airborne Battalion HQ (foot)
    -- _6TH_PARACHUTE_463 -- Airborne Commander 2
    do local units = join({_HQ_227, _6TH_PARACHUTE_463})
        if _1ST_6TH_PARACHUTE_COY_55_A_228_READY or
           _2ND_6TH_PARACHUTE_COY_55_A_232_READY or
           _3RD_6TH_PARACHUTE_COY_55_A_236_READY then
            if objective_owner(OBJECTIVES[24]) == VNA_SIDE then
                defend_normal(units, OBJECTIVES[24], NODIR, 0, 100)
            end
        end
    end

    -- _1ST_6TH_PARACHUTE_COY_55_A_228 -- 1st/6th Parachute Company 55 - A
    do local units = _1ST_6TH_PARACHUTE_COY_55_A_228
        _1ST_6TH_PARACHUTE_COY_55_A_228_READY = _1ST_6TH_PARACHUTE_COY_55_A_228_READY or ready(units)
        if _1ST_6TH_PARACHUTE_COY_55_A_228_READY then
            if not attack_sequential(units, {OBJECTIVES[24], OBJECTIVES[25], OBJECTIVES[27]}, ATTACK_STRONG, true) then
                defend_normal(units, OBJECTIVES[25])
            end
            if loss_rate(units) >= VNA_LOSS_RATE_TRIGGER then
                _1ST_6TH_PARACHUTE_COY_55_A_228_RETIRE_PT = _1ST_6TH_PARACHUTE_COY_55_A_228_RETIRE_PT or retire_point(units)
                defend_weak(units, _1ST_6TH_PARACHUTE_COY_55_A_228_RETIRE_PT, NODIR, 1)
            end
        end
    end

    -- _6TH_PARACHUTE_WEAPONS_COY_55_240 -- 6th Parachute Weapons Company 55
    do local units = _6TH_PARACHUTE_WEAPONS_COY_55_240
        _6TH_PARACHUTE_WEAPONS_COY_55_240_READY = _6TH_PARACHUTE_WEAPONS_COY_55_240_READY or ready(units)
        if _6TH_PARACHUTE_WEAPONS_COY_55_240_READY then
            if not attack_sequential(units, {OBJECTIVES[24], OBJECTIVES[25], OBJECTIVES[27]}, ATTACK_STRONG, true) then
                defend_normal(units, OBJECTIVES[27])
            end
            -- _81MM_MORTAR_244 -- Parachute M1 81mm Mortars
            if obj24_threatened then
                fire_indirect_nearest_to_hex(_81MM_MORTAR_244, OBJECTIVES[24], 100)
            elseif not at(_81MM_MORTAR_244, "82,15") then
                move_norush(_81MM_MORTAR_244, "82,15")
            elseif objective_owner(OBJECTIVES[25]) == BX_SIDE then
                fire_indirect_nearest_to_hex(_81MM_MORTAR_244, OBJECTIVES[25], 100)
            elseif objective_owner(OBJECTIVES[27]) == BX_SIDE then
                fire_indirect_nearest_to_hex(_81MM_MORTAR_244, OBJECTIVES[27], 100)
            end
            if loss_rate(units) >= VNA_LOSS_RATE_TRIGGER then
                _6TH_PARACHUTE_WEAPONS_COY_55_240_RETIRE_PT = _6TH_PARACHUTE_WEAPONS_COY_55_240_RETIRE_PT or retire_point(units)
                defend_weak(units, _6TH_PARACHUTE_WEAPONS_COY_55_240_RETIRE_PT, NODIR, 1)
            end
        end
    end

    do local units = difference(join({_1ST_6TH_PARACHUTE_COY_55_A_228,_6TH_PARACHUTE_WEAPONS_COY_55_240}), _81MM_MORTAR_244)
        if objective_owner(OBJECTIVES[24]) == VNA_SIDE then
            -- have the weakest unit among the 1st/6th & Weapons join in garrisoning and defending OBJECTIVES[24]
            _VNA_OBJECTIVES24_GARRISON = _VNA_OBJECTIVES24_GARRISON or random_pick(counters_weakest(units))
            defend_normal(_VNA_OBJECTIVES24_GARRISON, OBJECTIVES[24], NODIR, 0, 100)
            if objective_owner(OBJECTIVES[25]) == VNA_SIDE then
                -- have the second weakest unit among the 1st/6th & Weapons join in garrisoning and defending OBJECTIVES[25]
                _VNA_OBJECTIVES25_GARRISON = _VNA_OBJECTIVES25_GARRISON or random_pick(counters_weakest(difference(units,_VNA_OBJECTIVES24_GARRISON)))
                defend_normal(_VNA_OBJECTIVES25_GARRISON, OBJECTIVES[25], NODIR, 0, 100)
            end
        end
    end

    -- _2ND_6TH_PARACHUTE_COY_55_A_232 -- 2nd/6th Parachute Company 55 - A
    do local units = _2ND_6TH_PARACHUTE_COY_55_A_232
        _2ND_6TH_PARACHUTE_COY_55_A_232_READY = _2ND_6TH_PARACHUTE_COY_55_A_232_READY or ready(units)
        if _2ND_6TH_PARACHUTE_COY_55_A_232_READY then
            _2ND_6TH_PARACHUTE_COY_3RD_6TH_PARACHUTE_COY_ORDER = _2ND_6TH_PARACHUTE_COY_3RD_6TH_PARACHUTE_COY_ORDER or random_pick({1,1,2})
            if _2ND_6TH_PARACHUTE_COY_3RD_6TH_PARACHUTE_COY_ORDER == 1 then
                if not attack_sequential(units, {OBJECTIVES[24], OBJECTIVES[25], OBJECTIVES[27], OBJECTIVES[31], OBJECTIVES[33], OBJECTIVES[34]}, ATTACK_STRONG, true) then
                    defend_normal(units, OBJECTIVES[31])
                end
            else
                if not attack_sequential(units, {OBJECTIVES[24], OBJECTIVES[27], OBJECTIVES[31], OBJECTIVES[33], OBJECTIVES[34]}, ATTACK_STRONG, true) then
                    defend_normal(units, OBJECTIVES[31])
                end
            end
            -- if stuck at the major river at 91,20, unable to proceed due to pathfinding failure...
            if at(units, "91,20") and
               (hexai(units[1]) == OBJECTIVES[31]) and
               (aiorder(units[1]) == ATTACK_STRONG) then
                attack_way_point(units, {"92,19", OBJECTIVES[31]}, NODIR, 1, 100, ATTACK_STRONG)
            end
            if loss_rate(units) >= VNA_LOSS_RATE_TRIGGER then
                _2ND_6TH_PARACHUTE_COY_55_A_232_RETIRE_PT = _2ND_6TH_PARACHUTE_COY_55_A_232_RETIRE_PT or retire_point(units)
                defend_weak(units, _2ND_6TH_PARACHUTE_COY_55_A_232_RETIRE_PT, NODIR, 1)
            end
        end
    end

    -- _3RD_6TH_PARACHUTE_COY_55_A_236 -- 3rd/6th Parachute Company 55 - A
    do local units = _3RD_6TH_PARACHUTE_COY_55_A_236
        _3RD_6TH_PARACHUTE_COY_55_A_236_READY = _3RD_6TH_PARACHUTE_COY_55_A_236_READY or ready(units)
        if _3RD_6TH_PARACHUTE_COY_55_A_236_READY then
            _2ND_6TH_PARACHUTE_COY_3RD_6TH_PARACHUTE_COY_ORDER = _2ND_6TH_PARACHUTE_COY_3RD_6TH_PARACHUTE_COY_ORDER or random_pick({1,1,2})
            if _2ND_6TH_PARACHUTE_COY_3RD_6TH_PARACHUTE_COY_ORDER == 1 then
                attack_strong(units, OBJECTIVES[24])
                if owned(OBJECTIVES[25], VNA_SIDE) then
                    if not attack_sequential(units, {OBJECTIVES[27], OBJECTIVES[31], OBJECTIVES[33], OBJECTIVES[34]}, ATTACK_STRONG, true) then
                        defend_normal(units, "97,22")
                    end
                end
            else
                if not attack_sequential(units, {OBJECTIVES[24], OBJECTIVES[27], OBJECTIVES[31], OBJECTIVES[33], OBJECTIVES[34]}, ATTACK_STRONG, true) then
                    defend_normal(units, "97,22")
                end
            end
            -- if stuck at the major river at 91,20, unable to proceed due to pathfinding failure...
            if at(units, "91,20") and
               (hexai(units[1]) == OBJECTIVES[31]) and
               (aiorder(units[1]) == ATTACK_STRONG) then
                attack_way_point(units, {"92,19", OBJECTIVES[31]}, NODIR, 1, 100, ATTACK_STRONG)
            end
            if loss_rate(units) >= VNA_LOSS_RATE_TRIGGER then
                _3RD_6TH_PARACHUTE_COY_55_A_236_RETIRE_PT = _3RD_6TH_PARACHUTE_COY_55_A_236_RETIRE_PT or retire_point(units)
                defend_weak(units, _3RD_6TH_PARACHUTE_COY_55_A_236_RETIRE_PT, NODIR, 1)
            end
        end
    end

    if objective_owner(OBJECTIVES[34]) == VNA_SIDE then
        -- have the weakest unit among the 2nd/6th & 3rd/6th join in garrisoning and defending OBJECTIVES[34]
        _VNA_OBJECTIVES34_GARRISON = _VNA_OBJECTIVES34_GARRISON or random_pick(counters_weakest(join({_2ND_6TH_PARACHUTE_COY_55_A_232,_3RD_6TH_PARACHUTE_COY_55_A_236})))
        defend_normal(_VNA_OBJECTIVES34_GARRISON, OBJECTIVES[34], NODIR, 0, 100)
    end

    -------------------------------------------------------
    -- _NAVAL_ASSAULT_GROUPS_377 -- Naval Assault Groups --
    -------------------------------------------------------

    -- _10TH_NAVAL_ASSAULT_GROUP_379 -- 10th Naval Assault Group
    -- _1ST_PLT_380, _2ND_PLT_381, _3RD_PLT_382
    do local units = counters_active(join({_1ST_PLT_380, _2ND_PLT_381, _3RD_PLT_382}))
       local transports = counters_active(join({_LCVP_385, _LCVP_386, _LCVP_387}))
       local flotilla = join({units, transports})
       _10TH_NAVAL_ASSAULT_GROUP_379_MARINES_DISEMBARKED = _10TH_NAVAL_ASSAULT_GROUP_379_MARINES_DISEMBARKED or are_ground(units)
       if not _10TH_NAVAL_ASSAULT_GROUP_379_MARINES_DISEMBARKED then -- water transport to landing point
            if not at(units, "72,55") then
                if chance(100) then
--                if chance(50) then
                    move_way_point(flotilla, {"42,23", "49,35", "58,37", "63,37", "68,45", "67,49", "72,55"}, NODIR, 0, 100)
                else
                    move_fire_way_point(flotilla, {"42,23", "49,35", "58,37", "63,37", "68,45", "67,49", "72,55"}, NODIR, 2, 100)
                end
            else
                disembark(flotilla, "72,55", UPRIGHTDIR, 100)
            end
        else -- only if disembarked, on land
            if _10TH_NAVAL_ASSAULT_GROUP_379_SUPPORT_DISEMBARKED then -- wait for support
                if objective_owner(OBJECTIVES[18]) == BX_SIDE then
                    attack_strong(units, OBJECTIVES[18], UPDIR, 1, 100)
                elseif objective_owner(OBJECTIVES[21]) == BX_SIDE then
                    attack_strong(units, OBJECTIVES[21], UPDIR, 1, 100)
                end
                if not at(transports, "73,56") then
                    move_norush(transports, "73,56")
                else
                    fire_direct_nearest_to_hex (transports, OBJECTIVES[18])
                end
            end
        end
    end
    -- _MMG_48_383
    -- _81MM_MORTARS_384 -- Marine M1 81mm Mortars
    do local units = counters_active(join({_MMG_48_383, _81MM_MORTARS_384}))
       local transports = counters_active(join({_LCA_388, _LCA_389}))
       local flotilla = join({units, transports})
       _10TH_NAVAL_ASSAULT_GROUP_379_SUPPORT_DISEMBARKED = _10TH_NAVAL_ASSAULT_GROUP_379_SUPPORT_DISEMBARKED or are_ground(units)
       if not _10TH_NAVAL_ASSAULT_GROUP_379_SUPPORT_DISEMBARKED then
            -- water transport to landing point
            if not at(units, "72,54") then
                if chance(100) then
--                if chance(50) then
                    move_way_point(flotilla, {"42,23", "49,35", "58,37", "63,37", "68,45", "67,49", "72,54"}, NODIR, 0, 100)
                else
                    move_fire_way_point(flotilla, {"42,23", "49,35", "58,37", "63,37", "68,45", "67,49", "72,54"}, NODIR, 2, 100)
                end
            else
                disembark(flotilla, "72,54", UPRIGHTDIR, 100)
            end
        else -- only if disembarked, on land
            if _10TH_NAVAL_ASSAULT_GROUP_379_MARINES_DISEMBARKED then -- wait for marines
                if not at(_MMG_48_383, "74,55") then
                    move_rush(_MMG_48_383, "74,55") -- move to entrenched village
                else
                    fire_direct_nearest(_MMG_48_383, 100)
                end
                fire_indirect_nearest(_81MM_MORTARS_384, 100)
                if not at(transports, "73,56") then
                    move_norush(transports, "73,56")
                else
                    fire_direct_nearest_to_hex (transports, OBJECTIVES[18])
                end
            end
        end
    end

    -- _11TH_NAVAL_ASSAULT_GROUP_390 -- 11th Naval Assault Group
    -- _1ST_PLT_391, _2ND_PLT_392, _3RD_PLT_393
    do local units = counters_active(join({_1ST_PLT_391, _2ND_PLT_392, _3RD_PLT_393}))
       local transports = counters_active(join({_LCVP_396,_LCVP_397,_LCVP_398}))
       local flotilla = join({units, transports})
        _11TH_NAVAL_ASSAULT_GROUP_390_MARINES_DISEMBARKED = _11TH_NAVAL_ASSAULT_GROUP_390_MARINES_DISEMBARKED or are_ground(units) -- signals release transports for possible use by _2ND_1ST_PARACHUTE_COY_55_A_175
        if not _11TH_NAVAL_ASSAULT_GROUP_390_MARINES_DISEMBARKED then -- water transport to landing point
            if not at(units, "63,36") then
                if chance(100) then
--                if chance(50) then
                    move_way_point(flotilla, {"42,23", "49,35", "58,37", "63,36"}, NODIR, 0, 100)
                else
                    move_fire_way_point(flotilla, {"42,23", "49,35", "58,37", "63,36"}, NODIR, 2, 100)
                end
            else
                disembark(flotilla, "63,36", UPRIGHTDIR, 100)
            end
        else -- only if disembarked, on land
            attack_way_point(units, {"66,34", "68,35", "68,37", OBJECTIVES[14]}, DOWNRIGHTDIR, 0, 100, ATTACK_STRONG)
            if within(units, OBJECTIVES[14], NODIR, 1) then
                if not at(transports, "64,37") then
                    move_norush(transports, "64,37")
                else
                    fire_direct_nearest_to_hex (transports, OBJECTIVES[14])
                end
            end
        end
    end
    -- _HQ_378 -- VNMC Battalion HQ (foot)
    -- _MMG_48_394
    -- _81MM_MORTARS_395 -- Marine M1 81mm Mortars
    do local units = counters_active(join({_HQ_378, _MMG_48_394, _81MM_MORTARS_395}))
       local transports = counters_active(join({_LCA_399,_LCA_400,_LCP_412}))
       local flotilla = join({units, transports})
        _11TH_NAVAL_ASSAULT_GROUP_390_SUPPORT_DISEMBARKED = _11TH_NAVAL_ASSAULT_GROUP_390_SUPPORT_DISEMBARKED or are_ground(units) -- signals release transports for possible use by _2ND_1ST_PARACHUTE_COY_55_A_175
        if not _11TH_NAVAL_ASSAULT_GROUP_390_SUPPORT_DISEMBARKED then -- water transport to landing point
            if not at(units, "62,35") then
                if chance(100) then
--                if chance(50) then
                    move_way_point(flotilla, {"42,23", "49,35", "58,37", "62,35"}, NODIR, 0, 100)
                else
                    move_fire_way_point(flotilla, {"42,23", "49,35", "58,37", "62,35"}, NODIR, 2, 100)
                end
            else
                disembark(flotilla, "62,35", UPRIGHTDIR, 100)
            end
        else -- only if disembarked, on land
            if _11TH_NAVAL_ASSAULT_GROUP_390_MARINES_DISEMBARKED then -- so the MMGs don't prematurely get out too far ahead
                attack_way_point(_MMG_48_394, {"66,34", "68,35", "68,37", OBJECTIVES[14]}, DOWNRIGHTDIR, 0, 100, ATTACK_STRONG)
            end
            if not at(_81MM_MORTARS_395, "64,35") then
                move_norush(join({_HQ_378, _81MM_MORTARS_395}), "64,35")
            else
                fire_indirect_nearest_to_hex(_81MM_MORTARS_395, OBJECTIVES[14], 100, true)
                defend_weak(_HQ_378)
            end
            if within(_MMG_48_394, OBJECTIVES[14], NODIR, 1) then
                if not at(transports, "64,36") then
                    move_norush(transports, "64,36")
                else
                    fire_direct_nearest_to_hex (transports, OBJECTIVES[14])
                end
            end
        end
    end

    -- _LCP_412 -- Landing Craft Personnel
    do local units = _LCP_412

    end

    ---------------------------------------------------------------------------
    -- _3RD_ARTILLERY_BTN_55_105MM_413 -- 3rd Artillery Battalion 55 - 105mm --
    ---------------------------------------------------------------------------

    -- _HQ_414 -- ARVN Battalion HQ (foot)
    do local units = _HQ_414

    end

    -- _1ST_3RD_HOWITZER_BTY_55_105MMX4_415 -- 1st/3rd Howitzer Battery 55 - 105mmx4
    do local units = _1ST_3RD_HOWITZER_BTY_55_105MMX4_415

    end
    -- _HOWITZER_BTY_416 -- M101 105mm Howitzers

    -- _2ND_3RD_HOWITZER_BTY_55_105MMX4_420 -- 2nd/3rd Howitzer Battery 55 - 105mmx4
    do local units = _2ND_3RD_HOWITZER_BTY_55_105MMX4_420

    end
    -- _HOWITZER_BTY_421 -- M101 105mm Howitzers

    -- _3RD_3RD_HOWITZER_BTY_55_105MMX4_425 -- 3rd/3rd Howitzer Battery 55 - 105mmx4
    do local units = _3RD_3RD_HOWITZER_BTY_55_105MMX4_425

    end
    -- _HOWITZER_BTY_426 -- M101 105mm Howitzers

    -- _1ST_34TH_HOWITZER_BTY_55_105MMX4_0VP_431 -- 1st/34th Howitzer Battery 55 - 105mmx4 - 0VP
    do local units = _1ST_34TH_HOWITZER_BTY_55_105MMX4_0VP_431

    end
    -- _HOWITZER_BTY_432 -- M101 105mm Howitzers

    -- _M37_430 -- M37 3/4 ton truck
    do local units = _M37_430

    end

    -- _LIAISON_SQUADRON_55_O1_436 -- Liaison Squadron 55 - O-1
    do local units = _LIAISON_SQUADRON_55_O1_436

    end

    -- _LOGISTIC_55_LEVEL_2_263 -- Logistic 55 - Level 2
    do local units = _LOGISTIC_55_LEVEL_2_263

    end

    -- _SUPPLY_TRUCKS_266 -- Supply Trucks (VP)
    do local units = _SUPPLY_TRUCKS_266

    end

    -- _M35_267 -- M35 2 1/2 ton truck
    do local units = _M35_267

    end

    -- _GRUMMAN_F8F_BEARCAT_ROCKETS_503 -- Grumman F8F Bearcat {Rockets}
    do local units = _GRUMMAN_F8F_BEARCAT_ROCKETS_503

    end

    -- _GRUMMAN_F8F_BEARCAT_ROCKETS_504 -- Grumman F8F Bearcat {Rockets}
    do local units = _GRUMMAN_F8F_BEARCAT_ROCKETS_504

    end

    -- _GRUMMAN_F8F_BEARCAT_ROCKETS_505 -- Grumman F8F Bearcat {Rockets}
    do local units = _GRUMMAN_F8F_BEARCAT_ROCKETS_505

    end

    -- _GRUMMAN_F8F_BEARCAT_ROCKETS_506 -- Grumman F8F Bearcat {Rockets}
    do local units = _GRUMMAN_F8F_BEARCAT_ROCKETS_506

    end

    -- _GRUMMAN_F8F_BEARCAT_ROCKETS_507 -- Grumman F8F Bearcat {Rockets}
    do local units = _GRUMMAN_F8F_BEARCAT_ROCKETS_507

    end

    -- _GRUMMAN_F8F_BEARCAT_ROCKETS_508 -- Grumman F8F Bearcat {Rockets}
    do local units = _GRUMMAN_F8F_BEARCAT_ROCKETS_508

    end

    -- _DOUGLAS_B26_INVADER_BOMBS_509 -- Douglas B-26 Invader {Bombs}
    do local units = _DOUGLAS_B26_INVADER_BOMBS_509

    end

    -- _DOUGLAS_B26_INVADER_BOMBS_510 -- Douglas B-26 Invader {Bombs}
    do local units = _DOUGLAS_B26_INVADER_BOMBS_510

    end

    -- _DOUGLAS_B26_INVADER_BOMBS_511 -- Douglas B-26 Invader {Bombs}
    do local units = _DOUGLAS_B26_INVADER_BOMBS_511

    end

    -- _DOUGLAS_B26_INVADER_BOMBS_512 -- Douglas B-26 Invader {Bombs}
    do local units = _DOUGLAS_B26_INVADER_BOMBS_512

    end

    -- _DOUGLAS_B26_INVADER_BOMBS_513 -- Douglas B-26 Invader {Bombs}
    do local units = _DOUGLAS_B26_INVADER_BOMBS_513

    end

    -- _DOUGLAS_B26_INVADER_BOMBS_514 -- Douglas B-26 Invader {Bombs}
    do local units = _DOUGLAS_B26_INVADER_BOMBS_514

    end

    -- _DOUGLAS_B26_INVADER_BOMBS_515 -- Douglas B-26 Invader {Bombs}
    do local units = _DOUGLAS_B26_INVADER_BOMBS_515

    end

    -- _DOUGLAS_B26_INVADER_BOMBS_516 -- Douglas B-26 Invader {Bombs}
    do local units = _DOUGLAS_B26_INVADER_BOMBS_516

    end

end

------------------------------------------------------------------------------------------------------------------------

function battle_plan_b (turn, side)

    -- standard orders, uncomment as necessary:
    if turn == 1 then
        -- all Side B units hold initially (or maybe use halt())
        hold(ALLB)
    end

    -- don't act until turn 2, awaiting placement of logistic units (as first-turn reinforcements)
    if turn == 1 then
        return
    end

    -----------------------------------------------------------
    -- _BINH_XUYEN_PRIVATE_ARMY_1 -- Binh Xuyen Private Army --
    -----------------------------------------------------------

    -- _TRUNG_DOAN_HQ_2 -- VM Regimental HQ (foot)
    do local units = _TRUNG_DOAN_HQ_2
        defend_weak(units)
    end

    -- _BAY_VIEN_3 -- VM Commander 4
    do local units = _BAY_VIEN_3
        defend_weak(units)
    end

    ------------------------------------------------------------------------------------------
    -- _1ST_1ST_BINH_XUYEN_INF_BTN_48_US_4 -- 1st/1st Binh Xuyen Infantry Battalion 48 - US --
    ------------------------------------------------------------------------------------------

    -- _TIEU_DOAN_HQ_5 -- VM Battalion HQ (foot)
    do local units = _TIEU_DOAN_HQ_5
        defend_weak(units)
    end

    -- _C1_1ST_1ST_RIFLE_COY_48_US_6 -- C1/1st/1st Rifle Company 48 - US
    do local units = difference(_C1_1ST_1ST_RIFLE_COY_48_US_6, _MORTAR_10)
        if counter_exists(_C1_1ST_1ST_RIFLE_COY_48_US_6_POST) then
            local objective = counter_hex(_C1_1ST_1ST_RIFLE_COY_48_US_6_POST)
            if not within(units, objective, DOWNLEFTDIR, 2) then
                move_norush(units, objective, NODIR, 0, 100)
            else
                defend_scatter(units, objective, DOWNLEFTDIR, 2, 50, false, DEFEND_STRONG)
            end
            if not at(_MORTAR_10, objective) then
                move_rush(_MORTAR_10, objective, NODIR, 0, 100)
            else
                fire_indirect_nearest_to_hex(_MORTAR_10, objective, 100, true)
            end
        else
            defend_weak(units)
            fire_indirect_nearest(_MORTAR_10, 100, true)
        end
    end

    -- _C2_1ST_1ST_RIFLE_COY_48_US_11 -- C2/1st/1st Rifle Company 48 - US
    do local units = difference(_C2_1ST_1ST_RIFLE_COY_48_US_11, _MORTAR_15)
        if counter_exists(_C2_1ST_1ST_RIFLE_COY_48_US_11_POST) then
            local objective = counter_hex(_C2_1ST_1ST_RIFLE_COY_48_US_11_POST)
            if not within(units, objective, DOWNLEFTDIR, 2) then
                move_norush(units, objective, NODIR, 0, 100)
            else
                defend_scatter(units, objective, DOWNLEFTDIR, 2, 50, false, DEFEND_STRONG)
            end
            halt(_MORTAR_15)
            if not at(_MORTAR_15, objective) then
                move_rush(_MORTAR_15, objective, NODIR, 0, 100)
            else
                fire_indirect_nearest_to_hex(_MORTAR_15, objective, 100, true)
            end
        else
            defend_scatter(units, OBJECTIVES[22], DOWNLEFTDIR, 2, 50, false, DEFEND_NORMAL)
            fire_indirect_nearest(_MORTAR_15, 100, true)
        end
    end

    -- _C3_1ST_1ST_RIFLE_COY_48_US_16 -- C3/1st/1st Rifle Company 48 - US
    do local units = difference(_C3_1ST_1ST_RIFLE_COY_48_US_16, _MORTAR_20)
        if counter_exists(_C3_1ST_1ST_RIFLE_COY_48_US_16_POST) then
            local objective = counter_hex(_C3_1ST_1ST_RIFLE_COY_48_US_16_POST)
            if not within(units, objective, DOWNLEFTDIR, 2) then
                move_way_point(units, {"70,25",objective}, NODIR, 0, 100) -- see _JUNKS_163 below
            else
                defend_scatter(units, objective, DOWNLEFTDIR, 2, 50, true, DEFEND_STRONG)
            end
            if not at(_MORTAR_20, objective) then
                move_way_point(_MORTAR_20, {"70,25",objective}, NODIR, 0, 100)
            else
                fire_indirect_nearest_to_hex(_MORTAR_20, objective, 100, true)
            end
        else
            defend_weak(units)
            fire_indirect_nearest(_MORTAR_20, 100, true)
        end

    end

    -- _C4_1ST_1ST_DAI_DOI_HOA_LUC_48_81MM_21 -- C4/1st/1st Dai Doi Hoa Luc 48 - 81mm
    do local units = _C4_1ST_1ST_DAI_DOI_HOA_LUC_48_81MM_21
        defend_strong(units)
    end
    -- _MORTAR_22 -- VM 81mm Mortars
    fire_indirect_nearest(_MORTAR_22, 100, true)

    -------------------------------------------------------------------------------------------
    -- _1ST_2ND_BINH_XUYEN_INF_BTN_48_US_35 -- 1st/2nd Binh Xuyen Infantry Battalion 48 - US --
    -------------------------------------------------------------------------------------------

    -- _TIEU_DOAN_HQ_36 -- VM Battalion HQ (foot)
    do local units = _TIEU_DOAN_HQ_36
        defend_weak(units)
    end

    -- _C1_1ST_2ND_RIFLE_COY_48_US_37 -- C1/1st/2nd Rifle Company 48 - US
    do local units = difference(_C1_1ST_2ND_RIFLE_COY_48_US_37, _MORTAR_41)
        if _C1_1ST_2ND_RIFLE_COY_48_US_37_POST == "71,37" then
            local objective = _C1_1ST_2ND_RIFLE_COY_48_US_37_POST
            if not within(units, objective, DOWNLEFTDIR, 1) then
                move_norush(units, objective, NODIR, 0, 100)
            else
                defend_scatter(units, objective, DOWNLEFTDIR, 1, 50, true, DEFEND_STRONG)
            end
            if OBJECTIVES14_CAPTURE_TURN and
               turn >= OBJECTIVES14_CAPTURE_TURN + 5 then
                attack_strong(units, OBJECTIVES[14], DOWNRIGHTDIR, 1, 100)
            end
            halt(_MORTAR_41)
            if not at(_MORTAR_41, objective) then
                move_rush(_MORTAR_41, objective, NODIR, 0, 100)
            else
                fire_indirect_nearest_to_hex(_MORTAR_41, objective, 100, true)
            end
        else
            defend_strong(units)
            fire_indirect_nearest(_MORTAR_41, 100, true)
        end
    end

    -- _C2_1ST_2ND_RIFLE_COY_48_US_42 -- C2/1st/2nd Rifle Company 48 - US
    do local units = _C2_1ST_2ND_RIFLE_COY_48_US_42
        if counter_exists(_C2_1ST_2ND_RIFLE_COY_48_US_42_POST) then
            local objective = counter_hex(_C2_1ST_2ND_RIFLE_COY_48_US_42_POST)
            if not within(units, objective, UPLEFTDIR, 2) then
                move_norush(units, objective, NODIR, 0, 100)
            else
                defend_scatter(units, objective, UPLEFTDIR, 2, 50, true, DEFEND_STRONG)
            end
        else
            defend_weak(units)
        end
    end

    -- _C3_1ST_2ND_RIFLE_COY_48_US_47 -- C3/1st/2nd Rifle Company 48 - US
    do local units = _C3_1ST_2ND_RIFLE_COY_48_US_47
        local objective = _C3_1ST_2ND_RIFLE_COY_48_US_47_POST
        if _C3_1ST_2ND_RIFLE_COY_48_US_47_POST == "91,50" then -- defend _SUPPLY_DEPOT_486 at "91,50"
            if not within(units, objective, NODIR, 0) then
                move_norush(units, objective, NODIR, 0, 100)
            else
                defend_scatter(units, objective, NODIR, 1, 50, false, DEFEND_STRONG)
            end
        elseif _C3_1ST_2ND_RIFLE_COY_48_US_47_POST == OBJECTIVES[32] then
            defend_way_point(units, {"92,51", objective}, DOWNLEFTDIR, 1, 100, DEFEND_STRONG)
        elseif _C3_1ST_2ND_RIFLE_COY_48_US_47_POST == OBJECTIVES[28] then
            if not within(units, objective, DOWNDIR, 1) then
                move_way_point(units, {"88,56",objective}, NODIR, 0, 100) -- see _JUNKS_165 below
            else
                defend_strong(units, objective, DOWNDIR, 1, 100)
            end
        end
    end

    -- _C4_1ST_2ND_DAI_DOI_HOA_LUC_48_81MM_52 -- C4/1st/2nd Dai Doi Hoa Luc 48 - 81mm
    do local units = _C4_1ST_2ND_DAI_DOI_HOA_LUC_48_81MM_52
        defend_strong(units)
    end
    -- _MORTAR_53 -- VM 81mm Mortars
    fire_indirect_nearest(_MORTAR_53, 100, true)

    -------------------------------------------------------------------------------------------
    -- _1ST_5TH_BINH_XUYEN_INF_BTN_48_US_66 -- 1st/5th Binh Xuyen Infantry Battalion 48 - US --
    -------------------------------------------------------------------------------------------

    -- _TIEU_DOAN_HQ_67 -- VM Battalion HQ (foot)
    do local units = _TIEU_DOAN_HQ_67
        defend_weak(units)
    end

    -- _C1_1ST_5TH_RIFLE_COY_48_US_68 -- C1/1st/5th Rifle Company 48 - US
    do local units = _C1_1ST_5TH_RIFLE_COY_48_US_68
        defend_strong(units)
    end

    -- _C2_1ST_5TH_RIFLE_COY_48_US_73 -- C2/1st/5th Rifle Company 48 - US
    do local units = _C2_1ST_5TH_RIFLE_COY_48_US_73
        if counter_exists(_C2_1ST_5TH_RIFLE_COY_48_US_73_POST) then
            local objective = counter_hex(_C2_1ST_5TH_RIFLE_COY_48_US_73_POST)
            if not within(units, objective, DOWNLEFTDIR, 2) then            
                move_norush(units, objective, NODIR, 0, 100)
            else
                defend_scatter(units, objective, DOWNLEFTDIR, 2, 50, true, DEFEND_STRONG)
            end
        else
            defend_way_point(units, {"71,61", "73,61", OBJECTIVES[19]}, UPRIGHTDIR, 1, 100, DEFEND_STRONG)
        end
    end

    -- _C3_1ST_5TH_RIFLE_COY_48_US_78 -- C3/1st/5th Rifle Company 48 - US
    do local units = _C3_1ST_5TH_RIFLE_COY_48_US_78
        defend_strong(units)
    end
    -- _MORTAR_82 -- VM 50mm Mortars
    fire_indirect_nearest(_MORTAR_82, 100, true)

    -- _C4_1ST_5TH_DAI_DOI_HOA_LUC_48_81MM_83 -- C4/1st/5th Dai Doi Hoa Luc 48 - 81mm
    do local units = _C4_1ST_5TH_DAI_DOI_HOA_LUC_48_81MM_83
        defend_strong(units)
    end
    -- _MORTAR_84 -- VM 81mm Mortars
    fire_indirect_nearest(_MORTAR_84, 100, true)

    -- _LOGISTICS_COY_LEVEL_1_48_88 -- Logistics Company - Level 1 - 48
    do local units = _LOGISTICS_COY_LEVEL_1_48_88
        hold(units)
    end

    -- _SUPPLY_CACHE_95 -- Supply Cache (VP)
    do local units = _SUPPLY_CACHE_95
        hold(units)
    end

    -- _DAC_CONG_96 -- VM Engineer Platoon
    do local units = _DAC_CONG_96
        defend_strong(units)
    end

    -------------------------------------------------------------------------------------------
    -- _1ST_3RD_BINH_XUYEN_INF_BTN_48_US_97 -- 1st/3rd Binh Xuyen Infantry Battalion 48 - US --
    -------------------------------------------------------------------------------------------

    -- _TIEU_DOAN_HQ_98 -- VM Battalion HQ (foot)
    do local units = _TIEU_DOAN_HQ_98
        defend_weak(units)
    end

    -- _C1_1ST_3RD_RIFLE_COY_48_US_99 -- C1/1st/3rd Rifle Company 48 - US
    do local units = _C1_1ST_3RD_RIFLE_COY_48_US_99
        defend_strong(units)
    end
    -- _MORTAR_103 -- VM 50mm Mortars
    fire_indirect_nearest(_MORTAR_103, 100, true)

    -- _C2_1ST_3RD_RIFLE_COY_48_US_104 -- C2/1st/3rd Rifle Company 48 - US
    do local units = _C2_1ST_3RD_RIFLE_COY_48_US_104
        defend_strong(units)
        -- _2ND_VM_RIFLE_48_106 moves to reinforce OBJECTIVES[13] if that place is attacked (50/50 chance; see on_hex_attack())
        -- but if the unit is attacked en route, just (unload and) defend in place ever thereafter (general defend_strong() order (see above) still applies)
        if are_attacked(_2ND_VM_RIFLE_48_106) then
            if are_loaded(_2ND_VM_RIFLE_48_106) then
                unload(_2ND_VM_RIFLE_48_106)
            end
        else
            if _2ND_VM_RIFLE_48_106_REINFORCE == TRUE then
                move_wary_way_point(_2ND_VM_RIFLE_48_106, {"50,6","58,11"}, UPLEFTDIR, 2, 100, 1)
                if at(_2ND_VM_RIFLE_48_106, "48,7") then -- still at initial location, the Military Post at 48,7
                    if not are_carried(_2ND_VM_RIFLE_48_106) then
                        load(join({_2ND_VM_RIFLE_48_106,_MEDIUM_TRUCK_154})) -- if general hold() order
                    end
                elseif within(_2ND_VM_RIFLE_48_106, "58,11", NODIR, 1) then
                    if are_carried(_2ND_VM_RIFLE_48_106) then
                        unload(_2ND_VM_RIFLE_48_106)
                    else
                        defend_strong(_2ND_VM_RIFLE_48_106, OBJECTIVES[13], NODIR, 1, 100)
                    end
                end
            end
        end
    end

    -- _C3_1ST_3RD_RIFLE_COY_48_US_109 -- C3/1st/3rd Rifle Company 48 - US
    do local units = _C3_1ST_3RD_RIFLE_COY_48_US_109
        defend_strong(units)
    end

    -- _C4_1ST_3RD_DAI_DOI_HOA_LUC_48_81MM_114 -- C4/1st/3rd Dai Doi Hoa Luc 48 - 81mm
    do local units = _C4_1ST_3RD_DAI_DOI_HOA_LUC_48_81MM_114
        defend_strong(units)
    end
    -- _MORTAR_115 -- VM 81mm Mortars
    fire_indirect_nearest(_MORTAR_115, 100, true)

    -- _DAC_CONG_127 -- VM Engineer Platoon
    do local units = _DAC_CONG_127
        defend_strong(units)
    end

    -- _FIRE_SUPPORT_COY_50_82MM_128 -- Fire Support Company 50 - 82mm
    -- _RECONNAISSANCE_COY_50_133 -- Reconnaissance Company 50
    do local units = join({_FIRE_SUPPORT_COY_50_82MM_128, _RECONNAISSANCE_COY_50_133})
        defend_normal(units)
        _FIRE_SUPPORT_COY_50_82MM_128_ATTACK_TURN = _FIRE_SUPPORT_COY_50_82MM_128_ATTACK_TURN or random_pick({21,22,23,24,25})
        if turn >= _FIRE_SUPPORT_COY_50_82MM_128_ATTACK_TURN then
--        if turn >= 25 then
            if objective_owner(OBJECTIVES[13]) == VNA_SIDE then
                attack_strong(units, OBJECTIVES[13], NODIR, 1, 100)
            else
                -- attack any verified ARVN _3RD_ARTILLERY_BTN_55_105MM_413 units
                attack_org(units, _3RD_ARTILLERY_BTN_55_105MM_413, NODIR, 1, 100, ATTACK_NORMAL, true, false)
            end
        end
    end

    -- _LOGISTICS_COY_LEVEL_3_48_468 -- Logistics Company - Level 3 - 48
    do local units = _LOGISTICS_COY_LEVEL_3_48_468
        hold(units)
    end

    -- _LOGISTICS_COY_LEVEL_2_48_138 -- Logistics Company - Level 2 - 48
    do local units = _LOGISTICS_COY_LEVEL_2_48_138
        hold(units)
    end

    -- _LIGHT_TRUCK_150 -- Light Truck
    do local units = _LIGHT_TRUCK_150
        defend_weak(units)
    end

    -- _MEDIUM_TRUCK_153 -- Medium Truck
    do local units = _MEDIUM_TRUCK_153
        defend_weak(units)
    end

    -- _MEDIUM_TRUCK_154 -- Medium Truck
    do local units = _MEDIUM_TRUCK_154
        defend_weak(units)
    end

    -- _SAMPANS_157 -- Sampans
    do local units = _SAMPANS_157
        defend_weak(units)
    end

    -- _SAMPANS_158 -- Sampans
    do local units = _SAMPANS_158
        defend_weak(units)
    end

    -- _SAMPANS_159 -- Sampans
    do local units = _SAMPANS_159
        defend_weak(units)
    end

    -- _SAMPANS_160 -- Sampans
    do local units = _SAMPANS_160
        defend_weak(units)
    end

    -- _SAMPANS_161 -- Sampans
    do local units = _SAMPANS_161
        defend_weak(units)
    end

    -- _JUNKS_162 -- Junks
    do local units = _JUNKS_162
        defend_weak(units)
    end

    -- _JUNKS_163 -- Junks
    do local units = _JUNKS_163
        hold(units) -- ferries _C3_1ST_1ST_RIFLE_COY_48_US_16 across river
    end

    -- _JUNKS_164 -- Junks
    do local units = _JUNKS_164
        defend_weak(units)
    end

    -- _JUNKS_165 -- Junks
    do local units = _JUNKS_165
        hold(units) -- ferries _C3_1ST_2ND_RIFLE_COY_48_US_47 across river
    end

    -- _JUNKS_166 -- Junks
    do local units = _JUNKS_166
        defend_weak(units)
    end

    -- _AAMG_491 -- VM Anti-Aircraft Machine Gun
    do local units = _AAMG_491
        defend_normal(units)
    end

    -- _AAMG_492 -- VM Anti-Aircraft Machine Gun
    do local units = _AAMG_492
        defend_normal(units)
    end

    -- _AAMG_493 -- VM Anti-Aircraft Machine Gun
    do local units = _AAMG_493
        defend_normal(units)
    end

    -- _AAMG_494 -- VM Anti-Aircraft Machine Gun
    do local units = _AAMG_494
        defend_normal(units)
    end

    -- _SNIPER_495 -- VM Sniper
    do local units = _SNIPER_495
        defend_weak(units)
    end

    -- _SNIPER_496 -- VM Sniper
    do local units = _SNIPER_496
        defend_weak(units)
    end

    -- _SNIPER_497 -- VM Sniper
    do local units = _SNIPER_497
        defend_weak(units)
    end

    -- _SNIPER_498 -- VM Sniper
    do local units = _SNIPER_498
        defend_weak(units)
    end

    -- _SNIPER_499 -- VM Sniper
    do local units = _SNIPER_499
        defend_weak(units)
    end

    -- _57MM_RCLR_500 -- 57mm Recoilless Rifles
    do local units = _57MM_RCLR_500
        defend_normal(units)
    end

    -- _57MM_RCLR_501 -- 57mm Recoilless Rifles
    do local units = _57MM_RCLR_501
        defend_strong(units, OBJECTIVES[12])
    end

    if OBJECTIVES13_CAPTURED then
--    if turn >= 8 then
        -- erstwhile OBJECTIVES[13] defenders
        local units = join({_1ST_VM_RIFLE_48_105, _3RD_VM_RIFLE_48_107, _MEDIUM_MACHINE_GUN_116, _DAC_CONG_127})
        if counter_exists(_SUPPLY_CACHE_484) then
            defend_strong(units, counter_hex(_SUPPLY_CACHE_484))
        else
            defend_strong(units)
        end
    end

end

------------------------------------------------------------------------------------------------------------------------

function on_objective_capture (hc, value, values, side) -- DO NOT REMOVE

    if hc == OBJECTIVES[21] and side == VNA_SIDE then
        OBJECTIVES21_CAPTURED = true
    end

    if hc == OBJECTIVES[13] and side == VNA_SIDE then
        OBJECTIVES13_CAPTURED = true
    end

    if hc == OBJECTIVES[10] and side == VNA_SIDE then
        OBJECTIVES10_CAPTURED = true
    end

    -- for the above, EPs awarded in on_next_turn(), depending on the turn
    -- BX gain 25 EP for recapturing OBJECTIVES[13]
    if hc == OBJECTIVES[13] and side == BX_SIDE and
       OBJECTIVES13_CAPTURED == true and
       not OBJECTIVES13_RECAPTURED then -- one-time only award
        inc_event_points(BX_SIDE, 25)
        OBJECTIVES13_RECAPTURED = true
    end

    if hc == OBJECTIVES[14] and side == VNA_SIDE then
        OBJECTIVES14_CAPTURE_TURN = current_turn()
    end

    if chance(66) then -- two-in-three chance for player receiving a shout
        if side == VNA_SIDE then
            dialog("Commendations", ARVN_COMMENDATIONS[dieroll(#ARVN_COMMENDATIONS)], side, side)
        --  dialog("Commendations", VNA_COMMENDATIONS[dieroll(#VNA_COMMENDATIONS)], side, side)
        -- else
        --    dialog("Commendations", BX_COMMENDATIONS[dieroll(#BX_COMMENDATIONS)], side, side)
        end
    end

end

------------------------------------------------------------------------------------------------------------------------

function on_unit_move (hc_from, hc_to, trackid) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_unit_fire (hc, trackid, pid, name, side, nation, oid, orgname, strength) -- DO NOT REMOVE

    if side == SIDE_A then
        SIDE_A_FIRED = true
    elseif side == SIDE_B then
        SIDE_B_FIRED = true
    end

end

------------------------------------------------------------------------------------------------------------------------

function on_unit_arty_fire (hc, trackid, pid, name, side, nation, oid, orgname, strength) -- DO NOT REMOVE

    if side == SIDE_A then
        SIDE_A_ARTY_FIRED = true
    elseif side == SIDE_B then
        SIDE_B_ARTY_FIRED = true
    end

end

------------------------------------------------------------------------------------------------------------------------

function on_unit_attack (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader, attype) -- DO NOT REMOVE

    -- lose EPs for friendly fire arty or air attacks only
    if side == current_side() then -- side is the target side
        if attype == INDIRECTFIRE_COMBAT then
            inc_event_points(side, -5)
        elseif attype == AIRSTRIKE_COMBAT then
            inc_event_points(side, -10)
        end
    end



end

------------------------------------------------------------------------------------------------------------------------

function on_unit_reduce (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader, loss, combat) -- DO NOT REMOVE

    -- ARVN landing craft
    do local units = join({_LCVP_385, _LCVP_386, _LCVP_387, _LCA_388, _LCA_389, _LCVP_396, _LCVP_397, _LCVP_398, _LCA_399, _LCA_400})
       local award = 10
        if member(trackid, units) then
            inc_event_points(BX_SIDE, award*loss)
            dialog("Notice 1", "For destroying " .. loss .. " " .. counter_name(trackid) .. ", the BX side gains " .. award*loss .. " EPs.", BX_SIDE, BX_SIDE)
        end
    end

end 

------------------------------------------------------------------------------------------------------------------------

function on_unit_kill (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE

    -- ARVN kills

    -- HQ kills
    do local units = join({_VNA_HQ_460, _AIRBORNE_HQ_168})
       local award = 50
        if member(trackid, units) then
            inc_event_points(SIDE_B, award)
            dialog("Notice 2", "For destroying the " .. counter_name(trackid) .. ", the BX side gains " .. award .. " EPs.", BX_SIDE, BX_SIDE)
        end
    end

    -- HQ kills
    do local units = join({_HQ_271, _HQ_302, _HQ_170, _HQ_442, _HQ_227, _HQ_378, _HQ_414})
       local award = 25
        if member(trackid, units) then
            inc_event_points(SIDE_B, award)
            dialog("Notice 3", "For destroying the " .. counter_name(trackid) .. ", the BX side gains " .. award .. " EPs.", BX_SIDE, BX_SIDE)
        end
    end

    -- leader kills
    do local units = join({_1ST_PARACHUTE_461, _5TH_PARACHUTE_462, _6TH_PARACHUTE_463, _22ND_154TH_464, _58TH_154TH_465})
       local award = 25
        if member(trackid, units) then
            inc_event_points(SIDE_B, award)
            dialog("Notice 4", "For destroying the " .. counter_name(trackid) .. ", the BX side gains " .. award .. " EPs.", BX_SIDE, BX_SIDE)
        end
    end

    -- arty kills
    do local units = join({_HOWITZER_BTY_416, _HOWITZER_BTY_421, _HOWITZER_BTY_426, _HOWITZER_BTY_432})
       local award = 20
        if member(trackid, units) then
            inc_event_points(SIDE_B, award)
            dialog("Notice 5", "For destroying the " .. counter_name(trackid) .. ", the BX side gains " .. award .. " EPs.", BX_SIDE, BX_SIDE)
        end
    end

    -- aircraft
    do local units = _LIAISON_SQUADRON_55_O1_436
       local award = 35
        if member(trackid, units) then
            inc_event_points(SIDE_B, award)
            dialog("Notice 6", "For destroying the " .. counter_name(trackid) .. ", the BX side gains " .. award .. " EPs.", BX_SIDE, BX_SIDE)
        end
    end

    -- BX kills

    -- HQ kills
    do local units = _TRUNG_DOAN_HQ_2
       local award = 100
        if member(trackid, units) then
            inc_event_points(SIDE_A, award)
            dialog("Notice 7", "For destroying the " .. counter_name(trackid) .. ", the ARVN side gains " .. award .. " EPs.", VNA_SIDE, VNA_SIDE)
        end
    end

    -- HQ kills
    do local units = join({_TIEU_DOAN_HQ_5, _TIEU_DOAN_HQ_36, _TIEU_DOAN_HQ_67, _TIEU_DOAN_HQ_98})
       local award = 50
        if member(trackid, units) then
            inc_event_points(SIDE_A, award)
            dialog("Notice 8", "For destroying the " .. counter_name(trackid) .. ", the ARVN side gains " .. award .. " EPs.", VNA_SIDE, VNA_SIDE)
        end
    end

    -- logistics
    do local units = join({_LOGISTICS_COY_LEVEL_3_48_468, _LOGISTICS_COY_LEVEL_2_48_138})
       local award = 100
        if member(trackid, units) then
            inc_event_points(SIDE_A, award)
            dialog("Notice 9", "For destroying the " .. counter_name(trackid) .. ", the ARVN side gains " .. award .. " EPs.", VNA_SIDE, VNA_SIDE)
        end
    end

end

------------------------------------------------------------------------------------------------------------------------

function on_unit_reinforce (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE
    
    halt(trackid)

end

------------------------------------------------------------------------------------------------------------------------

-- NOTE:  there are no hc hex coordinates for on_unit_release()

function on_unit_release (trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------

function on_unit_remove (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------ 

-- NOTE:  0 is superior (surviving) unit, 1 is subordinate (disappearing) unit

function on_unit_merge (hc, trackid0, pid0, name0, side0, nation0, oid0, orgname0, points0, strength0, HQ0, Leader0, trackid1, pid1, name1, side1, nation1, oid1, orgname1, points1, strength1, HQ1, Leader1) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------

function on_unit_to_top (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------

function on_unit_to_bottom (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------

function on_unit_clockwise (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------

function on_unit_counterclockwise (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------

function on_hex_attack (hc, side, nation, attype) -- DO NOT REMOVE

    -- lose EPs for indirect fire or airstrike vs. inhabited hex (village, city, suburb), whether or not occupied by the enemy
    -- side is the firing side
    if -- is_building_hex(hc) or
       is_habitat_hex(hc) then
        if not_occupied(hc, other_side(side)) then
            if attype == INDIRECTFIRE_COMBAT then
                inc_event_points(side, -2)
            elseif attype == AIRSTRIKE_COMBAT then
                inc_event_points(side, -5)
            end
        else -- occupied
            if attype == INDIRECTFIRE_COMBAT then
                inc_event_points(side, -1)
            elseif attype == AIRSTRIKE_COMBAT then
                inc_event_points(side, -2)
            end
        end
    end

    if not _2ND_VM_RIFLE_48_106_REINFORCE and -- determine this one time only
       member(hc, hexes_within(OBJECTIVES[13], NODIR, 1)) and
       side == VNA_SIDE then
        if dieroll(100) <= 50 then -- 50/50 chance
            _2ND_VM_RIFLE_48_106_REINFORCE = TRUE
        else
            _2ND_VM_RIFLE_48_106_REINFORCE = FALSE
        end
    end

end

------------------------------------------------------------------------------------------------------------------------ 

function on_hex_assault (hc, side) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------

function on_air_attack (hc, pid, name, side, nation, points, strength) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------

function on_arty_attack (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE



end

------------------------------------------------------------------------------------------------------------------------ 

function on_mine_attack (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE 



end 

------------------------------------------------------------------------------------------------------------------------

function on_ied_attack (hc, trackid, pid, name, side, nation, oid, orgname, points, strength, HQ, Leader) -- DO NOT REMOVE 



end 

------------------------------------------------------------------------------------------------------------------------

function on_build_vehicle_bridge (hc, dir, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_build_light_bridge (hc, dir, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_lay_mine_field (hc, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_set_ied (hc, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_build_barrier (hc, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_damage (hc, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_improve_hex (hc, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_entrench_hex (hc, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_clear_lz (hc, trackid, pid, name, side, nation, oid, orgname) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function on_clear_hex (hc) -- DO NOT REMOVE



end 

------------------------------------------------------------------------------------------------------------------------

function retire_point (trackids)

    local ca = counters_active(trackids)
    if #ca > 0 then
        local side = counter_side(ca[1])
        local oside = other_side(side)
        local cch = counters_center_hex(ca)
        local hno = hexes_not_occupied (hexes_habitat(), oside)
        local hn = hexes_nearest (cch, hno)
        if #hn > 0 then
            return random_pick(hn)
        end
    end
    return HEXUNKNOWN

end

------------------------------------------------------------------------------------------------------------------------

function ready (trackids)

    local ca = counters_active(trackids)
    if (member_count(ca) > 0) and
       are_not_disrupted(ca) then
        return true
    else
        return false
    end

end

------------------------------------------------------------------------------------------------------------------------
